@@ -1,6 +1,5 @@
-// $Id$
 //
-//  Copyright (C) 2005-2008 Greg Landrum and Rational Discovery LLC
+//  Copyright (C) 2005-2019 Greg Landrum and Rational Discovery LLC
 //
 //  @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -15,6 +14,7 @@
 #include <Geometry/point.h>
 #include <iostream>
 #include <RDGeneral/Invariant.h>
+#include <RDGeneral/utils.h>
 
 using namespace ChemicalFeatures;
 
@@ -22,26 +22,38 @@ void test1() {
   std::cout << "-----------------------------------------" << std::endl;
   std::cout << "Test1" << std::endl;
 
-  FreeChemicalFeature f1("foo", "bar", RDGeom::Point3D(0, 0, 0));
+  FreeChemicalFeature f1("foo", "bar", RDGeom::Point3D(1, 1, 1));
   TEST_ASSERT(f1.getId() == -1);
   TEST_ASSERT(f1.getFamily() == "foo");
   TEST_ASSERT(f1.getType() == "bar");
+  TEST_ASSERT(RDKit::feq(f1.getPos().x, 1.0));
+  TEST_ASSERT(RDKit::feq(f1.getPos().y, 1.0));
+  TEST_ASSERT(RDKit::feq(f1.getPos().z, 1.0));
 
-  FreeChemicalFeature f2("foo", "bar", RDGeom::Point3D(0, 0, 0), 123);
+  FreeChemicalFeature f2("foo", "bar", RDGeom::Point3D(1, 1, 1), 123);
   TEST_ASSERT(f2.getId() == 123);
   TEST_ASSERT(f2.getFamily() == "foo");
   TEST_ASSERT(f2.getType() == "bar");
+  TEST_ASSERT(RDKit::feq(f2.getPos().x, 1.0));
+  TEST_ASSERT(RDKit::feq(f2.getPos().y, 1.0));
+  TEST_ASSERT(RDKit::feq(f2.getPos().z, 1.0));
 
   FreeChemicalFeature f3;
   f3.initFromString(f2.toString());
   TEST_ASSERT(f3.getId() == 123);
   TEST_ASSERT(f3.getFamily() == "foo");
   TEST_ASSERT(f3.getType() == "bar");
+  TEST_ASSERT(RDKit::feq(f3.getPos().x, 1.0));
+  TEST_ASSERT(RDKit::feq(f3.getPos().y, 1.0));
+  TEST_ASSERT(RDKit::feq(f3.getPos().z, 1.0));
 
-  FreeChemicalFeature f4(f2.toString());
+  FreeChemicalFeature f4(f2);
   TEST_ASSERT(f4.getId() == 123);
   TEST_ASSERT(f4.getFamily() == "foo");
   TEST_ASSERT(f4.getType() == "bar");
+  TEST_ASSERT(RDKit::feq(f4.getPos().x, 1.0));
+  TEST_ASSERT(RDKit::feq(f4.getPos().y, 1.0));
+  TEST_ASSERT(RDKit::feq(f4.getPos().z, 1.0));
 
   std::cout << "Done" << std::endl;
 }
