@@ -24,14 +24,15 @@ namespace DistGeom {
   with lower distance bounds on the lower traingle and upper bounds in the upper
   triangle
 */
-class RDKIT_DISTGEOMETRY_EXPORT BoundsMatrix : public RDNumeric::SquareMatrix<double> {
+class RDKIT_DISTGEOMETRY_EXPORT BoundsMatrix
+    : public RDNumeric::SquareMatrix<double> {
  public:
   typedef boost::shared_array<double> DATA_SPTR;
 
   explicit BoundsMatrix(unsigned int N)
-      : RDNumeric::SquareMatrix<double>(N, 0.0){};
+      : RDNumeric::SquareMatrix<double>(N, 0.0) {}
   BoundsMatrix(unsigned int N, DATA_SPTR data)
-      : RDNumeric::SquareMatrix<double>(N, data){};
+      : RDNumeric::SquareMatrix<double>(N, data) {}
 
   //! Get the upper bound between points i and j
   inline double getUpperBound(unsigned int i, unsigned int j) const {
@@ -115,6 +116,6 @@ class RDKIT_DISTGEOMETRY_EXPORT BoundsMatrix : public RDNumeric::SquareMatrix<do
 };
 
 typedef boost::shared_ptr<BoundsMatrix> BoundsMatPtr;
-}
+}  // namespace DistGeom
 
 #endif
