@@ -22,7 +22,7 @@ class MMFFBondStretchEmpiricalRule;
 //! The bond-stretch term for MMFF
 class RDKIT_FORCEFIELD_EXPORT BondStretchContrib : public ForceFieldContrib {
  public:
-  BondStretchContrib()  {};
+  BondStretchContrib() {}
   //! Constructor
   /*!
     \param owner       pointer to the owning ForceField
@@ -36,18 +36,18 @@ class RDKIT_FORCEFIELD_EXPORT BondStretchContrib : public ForceFieldContrib {
   BondStretchContrib(ForceField *owner, const unsigned int idx1,
                      const unsigned int idx2, const MMFFBond *mmffBondParams);
 
-  double getEnergy(double *pos) const;
+  double getEnergy(double *pos) const override;
 
-  void getGrad(double *pos, double *grad) const;
+  void getGrad(double *pos, double *grad) const override;
 
-  virtual BondStretchContrib *copy() const {
+  BondStretchContrib *copy() const override {
     return new BondStretchContrib(*this);
-  };
+  }
 
  private:
   int d_at1Idx{-1}, d_at2Idx{-1};  //!< indices of end points
-  double d_r0;             //!< rest length of the bond
-  double d_kb;             //!< force constant of the bond
+  double d_r0;                     //!< rest length of the bond
+  double d_kb;                     //!< force constant of the bond
 };
 
 namespace Utils {
