@@ -23,7 +23,7 @@ namespace UFF {
 class RDKIT_FORCEFIELD_EXPORT PositionConstraintContrib
     : public ForceFieldContrib {
  public:
-  PositionConstraintContrib()  {};
+  PositionConstraintContrib() {}
   //! Constructor
   /*!
     \param owner       pointer to the owning ForceField
@@ -36,16 +36,16 @@ class RDKIT_FORCEFIELD_EXPORT PositionConstraintContrib
   PositionConstraintContrib(ForceField *owner, unsigned int idx,
                             double maxDispl, double forceConst);
 
-  ~PositionConstraintContrib() {}
-  double getEnergy(double *pos) const;
+  ~PositionConstraintContrib() override = default;
+  double getEnergy(double *pos) const override;
 
-  void getGrad(double *pos, double *grad) const;
-  virtual PositionConstraintContrib *copy() const {
+  void getGrad(double *pos, double *grad) const override;
+  PositionConstraintContrib *copy() const override {
     return new PositionConstraintContrib(*this);
-  };
+  }
 
  private:
-  int d_atIdx{-1};             //!< index of the restrained atom
+  int d_atIdx{-1};         //!< index of the restrained atom
   double d_maxDispl;       //!< maximum allowed displacement
   RDGeom::Point3D d_pos0;  //!< reference position
   double d_forceConstant;  //!< force constant of the bond
