@@ -9,7 +9,6 @@
 //
 #include "Abbreviations.h"
 #include <GraphMol/RDKitBase.h>
-#include <GraphMol/Substruct/SubstructMatch.h>
 #include <RDGeneral/types.h>
 #include <RDGeneral/Invariant.h>
 
@@ -21,13 +20,22 @@ namespace RDKit {
 namespace Abbreviations {
 
 void applyMatches(RWMol& mol, const std::vector<AbbreviationMatch>& matches) {
-  boost::dynamic_bitset<> toRemove(mol.getNumAtoms());
+  boost::dynamic_bitset<> atomsToRemove(mol.getNumAtoms());
+  boost::dynamic_bitset<> bondsToRemove(mol.getNumBonds());
+  std::vector<unsigned int> prevAtomMapping;
+  std::vector<unsigned int> prevBondMapping;
+  std::vector<unsigned int> addedBonds;
+  addedBonds.reserve(mol.getNumBonds());
+  bool hasPrevMapping =
+      mol.getPropIfPresent(common_properties::origAtomMapping,
+                           prevAtomMapping) &&
+      mol.getPropIfPresent(common_properties::origBondMapping, prevBondMapping);
   for (const auto& amatch : matches) {
     // throughout this remember that atom 0 in the match is the dummy
 
     // convert atom 1 to be the abbreviation so that we don't have to
     // worry about messing up chirality, etc.
-    auto connectIdx = amatch.match[1].second;
+    auto connectIdx = amatch.match.at(1).second;
     auto connectingAtom = mol.getAtomWithIdx(connectIdx);
     connectingAtom->setProp(RDKit::common_properties::atomLabel,
                             amatch.abbrev.label);
@@ -49,38 +57,72 @@ void applyMatches(RWMol& mol, const std::vector<AbbreviationMatch>& matches) {
     connectingAtom->setHybridization(Atom::HybridizationType::SP);
 
     for (unsigned int i = 2; i < amatch.match.size(); ++i) {
-      const auto& pr = amatch.match[i];
-      CHECK_INVARIANT(!toRemove[pr.second], "overlapping matches");
-      toRemove.set(pr.second);
+      const auto& pr = amatch.match.at(i);
+      CHECK_INVARIANT(!atomsToRemove[pr.second], "overlapping matches");
+      atomsToRemove.set(pr.second);
+      for (const auto bond : mol.atomBonds(mol.getAtomWithIdx(pr.second))) {
+        bondsToRemove.set(bond->getIdx());
+      }
       // if there's a molecule associated with the match, check to see if
       // additional bonds need to be formed
       if (amatch.abbrev.mol &&
           mol.getAtomWithIdx(pr.second)->getDegree() >
               amatch.abbrev.mol->getAtomWithIdx(pr.first)->getDegree()) {
-        for (auto nbrIdx : boost::make_iterator_range(
-                 mol.getAtomNeighbors(mol.getAtomWithIdx(pr.second)))) {
+        for (const auto bond : mol.atomBonds(mol.getAtomWithIdx(pr.second))) {
           // if this neighbor isn't in the match:
+          auto nbrIdx = bond->getOtherAtomIdx(pr.second);
           if (!std::any_of(amatch.match.begin(), amatch.match.end(),
                            [nbrIdx](const std::pair<int, int>& tpr) {
                              return tpr.second == rdcast<int>(nbrIdx);
                            })) {
             mol.addBond(nbrIdx, connectIdx, Bond::BondType::SINGLE);
+            addedBonds.push_back(hasPrevMapping
+                                     ? prevBondMapping.at(bond->getIdx())
+                                     : bond->getIdx());
           }
         }
       }
     }
     // make connections between any extraAttachAtoms and the connection point
     for (auto oaidx : amatch.abbrev.extraAttachAtoms) {
+      int bondIdx = -1;
+      for (const auto bond : mol.atomBonds(mol.getAtomWithIdx(oaidx))) {
+        if (bondsToRemove.test(bond->getIdx())) {
+          CHECK_INVARIANT(bondIdx == -1, "bondIdx must be unique");
+          bondIdx = bond->getIdx();
+        }
+      }
+      CHECK_INVARIANT(bondIdx != -1, "bondIdx not found");
       mol.addBond(oaidx, connectIdx, Bond::BondType::SINGLE);
+      addedBonds.push_back(hasPrevMapping ? prevBondMapping.at(bondIdx)
+                                          : bondIdx);
     }
   }
+  std::vector<unsigned int> atomMapping;
+  atomMapping.reserve(mol.getNumAtoms());
+  std::vector<unsigned int> bondMapping;
+  bondMapping.reserve(mol.getNumBonds());
   mol.beginBatchEdit();
-  for (unsigned int i = 0; i < toRemove.size(); ++i) {
-    if (toRemove[i]) {
+  for (unsigned int i = 0; i < atomsToRemove.size(); ++i) {
+    if (atomsToRemove[i]) {
       mol.removeAtom(i);
+    } else {
+      atomMapping.push_back(hasPrevMapping ? prevAtomMapping.at(i) : i);
+    }
+  }
+  for (unsigned int i = 0; i < bondsToRemove.size(); ++i) {
+    if (!bondsToRemove[i]) {
+      bondMapping.push_back(hasPrevMapping ? prevBondMapping.at(i) : i);
     }
   }
   mol.commitBatchEdit();
+  bondMapping.insert(bondMapping.end(), addedBonds.begin(), addedBonds.end());
+  CHECK_INVARIANT(atomMapping.size() == mol.getNumAtoms(),
+                  "atomMapping mismatch");
+  CHECK_INVARIANT(bondMapping.size() == mol.getNumBonds(),
+                  "bondMapping mismatch");
+  mol.setProp(common_properties::origAtomMapping, atomMapping);
+  mol.setProp(common_properties::origBondMapping, bondMapping);
 }
 
 void labelMatches(RWMol& mol, const std::vector<AbbreviationMatch>& matches) {
