@@ -688,9 +688,7 @@ void molRemoveH(RWMol &mol, unsigned int idx, bool updateExplicitCount) {
     // atom.  We deal with that by explicitly checking here:
     if (heavyAtom->getChiralTag() != Atom::CHI_UNSPECIFIED) {
       INT_LIST neighborIndices;
-      for (const auto &nbri :
-           boost::make_iterator_range(mol.getAtomBonds(heavyAtom))) {
-        Bond *nbnd = mol[nbri];
+      for (const auto &nbnd : mol.atomBonds(heavyAtom)) {
         if (nbnd->getIdx() != bond->getIdx()) {
           neighborIndices.push_back(nbnd->getIdx());
         }
@@ -705,6 +703,20 @@ void molRemoveH(RWMol &mol, unsigned int idx, bool updateExplicitCount) {
       }
     }
 
+    // If we are removing a H atom that defines bond stereo (e.g. imines),
+    // Then also remove the bond stereo information, as it is no longer valid.
+    if (heavyAtom->getDegree() == 2) {
+      for (auto &nbnd : mol.atomBonds(heavyAtom)) {
+        if (nbnd != bond) {
+          if (nbnd->getStereo() > Bond::STEREOANY) {
+            nbnd->setStereo(Bond::STEREONONE);
+            nbnd->getStereoAtoms().clear();
+          }
+          break;
+        }
+      }
+    }
+
     // if it's a wavy bond, then we need to
     // mark the beginning atom with the _UnknownStereo tag.
     // so that we know later that something was affecting its
@@ -1063,7 +1075,13 @@ ROMol *removeAllHs(const ROMol &mol, bool sanitize) {
 }
 
 namespace {
-bool isQueryH(const Atom *atom) {
+enum class HydrogenType {
+  NotAHydrogen,
+  UnMergableQueryHydrogen,
+  QueryHydrogen
+};
+
+HydrogenType isQueryH(const Atom *atom) {
   PRECONDITION(atom, "bogus atom");
   if (atom->getAtomicNum() == 1) {
     // the simple case: the atom is flagged as being an H and
@@ -1071,18 +1089,18 @@ bool isQueryH(const Atom *atom) {
     if (!atom->hasQuery() ||
         (!atom->getQuery()->getNegation() &&
          atom->getQuery()->getDescription() == "AtomAtomicNum")) {
-      return true;
+      return HydrogenType::QueryHydrogen;
     }
   }
 
   if (!(atom->getDegree() <= 1)) {
     // bonded and unbonded H atoms will continue rest will be returned
-    return false;
+    return HydrogenType::NotAHydrogen;
   }
 
   if (atom->hasQuery() && atom->getQuery()->getNegation()) {
     // we will not merge negated queries
-    return false;
+    return HydrogenType::NotAHydrogen;
   }
 
   bool hasHQuery = false, hasOr = false;
@@ -1119,10 +1137,10 @@ bool isQueryH(const Atom *atom) {
                                  "in ORs is not supported. This query will not "
                                  "be merged"
                               << std::endl;
-      return false;
+      return HydrogenType::UnMergableQueryHydrogen;
     }
   }
-  return hasHQuery;
+  return hasHQuery ? HydrogenType::QueryHydrogen : HydrogenType::NotAHydrogen;
 }
 }  // namespace
 
@@ -1145,7 +1163,7 @@ void mergeQueryHs(RWMol &mol, bool mergeUnmappedOnly, bool mergeIsotopes) {
 
   boost::dynamic_bitset<> hatoms(mol.getNumAtoms());
   for (unsigned int i = 0; i < mol.getNumAtoms(); ++i) {
-    hatoms[i] = isQueryH(mol.getAtomWithIdx(i));
+    hatoms[i] = isQueryH(mol.getAtomWithIdx(i)) == HydrogenType::QueryHydrogen;
   }
   unsigned int currIdx = 0, stopIdx = mol.getNumAtoms();
   while (currIdx < stopIdx) {
@@ -1263,5 +1281,56 @@ bool needsHs(const ROMol &mol) {
   return false;
 }
 
+std::pair<bool, bool> hasQueryHs(const ROMol &mol) {
+  bool queryHs = false;
+  // We don't care about announcing ORs or other items during isQueryH
+  RDLog::LogStateSetter blocker;
+
+  for (const auto atom : mol.atoms()) {
+    switch (isQueryH(atom)) {
+      case HydrogenType::UnMergableQueryHydrogen:
+        return std::make_pair(true, true);
+      case HydrogenType::QueryHydrogen:
+        queryHs = true;
+        break;
+      default:  // HydrogenType::NotAHydrogen:
+        break;
+    }
+    if (atom->hasQuery()) {
+      if (atom->getQuery()->getDescription() == "RecursiveStructure") {
+        auto *rsq = dynamic_cast<RecursiveStructureQuery *>(atom->getQuery());
+        CHECK_INVARIANT(rsq, "could not convert recursive structure query");
+        auto res = hasQueryHs(*rsq->getQueryMol());
+        if (res.second) {  // unmergableH implies queryH
+          return res;
+        }
+        queryHs |= res.first;
+      }
+
+      // FIX: shouldn't be repeating this code here -- yet again!
+      std::list<QueryAtom::QUERYATOM_QUERY::CHILD_TYPE> childStack(
+          atom->getQuery()->beginChildren(), atom->getQuery()->endChildren());
+      while (!childStack.empty()) {
+        QueryAtom::QUERYATOM_QUERY::CHILD_TYPE qry = childStack.front();
+        childStack.pop_front();
+        if (qry->getDescription() == "RecursiveStructure") {
+          auto *rsq = dynamic_cast<RecursiveStructureQuery *>(qry.get());
+          CHECK_INVARIANT(rsq, "could not convert recursive structure query");
+          auto res = hasQueryHs(*rsq->getQueryMol());
+          if (res.second) {
+            return res;
+          }
+          queryHs |= res.first;
+        } else {
+          childStack.insert(childStack.end(), qry->beginChildren(),
+                            qry->endChildren());
+        }
+      }
+    }
+  }  // end of recursion loop
+
+  return std::make_pair(queryHs, false);
+}
+
 }  // namespace MolOps
 }  // namespace RDKit
