@@ -49,6 +49,10 @@ const Sort *SequenceRule::getSorter() const {
 }
 
 int SequenceRule::recursiveCompare(const Edge *a, const Edge *b) const {
+  if (!CIPLabeler_detail::decrementRemainingCallCountAndCheck()) {
+    throw MaxIterationsExceeded();
+  }
+
   int cmp = compare(a, b);
   if (cmp != 0) {
     return cmp;
