@@ -81,7 +81,8 @@ RDKIT_CHEMREACTIONS_EXPORT std::vector<MOL_SPTR_VECT> run_Reactant(
     unsigned int reactantIdx);
 
 RDKIT_CHEMREACTIONS_EXPORT bool run_Reactant(const ChemicalReaction& rxn,
-                                             RWMol& reactant);
+                                             RWMol& reactant,
+                                             bool removeUnmatchedAtoms = true);
 
 //! Reduce the product generated by run_Reactants or run_Reactant to
 /// the sidechains that come from the reagents
