@@ -80,8 +80,9 @@ bool hasReactionMoleculeTemplateSubstructMatch(
        ++begin) {
     for (auto begin_query = getStartIterator(query_rxn, t);
          begin_query != getEndIterator(query_rxn, t); ++begin_query) {
-      MatchVectType tvect;
-      if (SubstructMatch(*begin->get(), *begin_query->get(), tvect)) {
+      auto tvect = SubstructMatch(*begin->get(), *begin_query->get(),
+                                  rxn.getSubstructParams());
+      if (!tvect.empty()) {
         return true;
       }
     }
