@@ -103,14 +103,18 @@ std::string chemicalReactionToRxnToString(const RDKit::ChemicalReaction &rxn,
 }
 
 void write_template(std::ostringstream &res, RDKit::ROMol &tpl) {
-  if (tpl.needsUpdatePropertyCache()) {
-    tpl.updatePropertyCache(false);
+  RDKit::RWMol trwmol(tpl);
+
+  if (trwmol.needsUpdatePropertyCache()) {
+    trwmol.updatePropertyCache(false);
   }
   // to write the mol block, we need ring information:
-  if (!tpl.getRingInfo()->isInitialized()) {
-    RDKit::MolOps::findSSSR(tpl);
+  if (!trwmol.getRingInfo()->isInitialized()) {
+    RDKit::MolOps::findSSSR(trwmol);
   }
-  res << RDKit::FileParserUtils::getV3000CTAB(tpl, -1);
+  RDKit::FileParserUtils::moveAdditionalPropertiesToSGroups(trwmol);
+
+  res << RDKit::FileParserUtils::getV3000CTAB(trwmol, -1);
 }
 
 }  // namespace
