@@ -1,5 +1,5 @@
 //
-//  Copyright (c) 2007-2021, Novartis Institutes for BioMedical Research Inc.
+//  Copyright (c) 2007-2023, Novartis Institutes for BioMedical Research Inc.
 //  and other RDKit contributors
 //
 //  All rights reserved.
@@ -40,6 +40,7 @@
 #include <GraphMol/ChemReactions/ReactionRunner.h>
 #include <GraphMol/ChemReactions/PreprocessRxn.h>
 #include <GraphMol/ChemReactions/SanitizeRxn.h>
+#include <GraphMol/MarvinParse/MarvinParser.h>
 #include <GraphMol/Depictor/DepictUtils.h>
 #include <GraphMol/FilterCatalog/FunctionalGroupHierarchy.h>
 
@@ -67,6 +68,15 @@ void rdChemicalReactionExceptionTranslator(
 }
 
 namespace RDKit {
+std::string pyObjectToString(python::object input) {
+  python::extract<std::string> ex(input);
+  if (ex.check()) {
+    return ex();
+  }
+  std::wstring ws = python::extract<std::wstring>(input);
+  return std::string(ws.begin(), ws.end());
+}
+
 python::object ReactionToBinaryWithProps(const ChemicalReaction &self,
                                          unsigned int props) {
   std::string res;
@@ -123,10 +133,9 @@ PyObject *RunReactants(ChemicalReaction *self, T reactants,
   return res;
 }
 
-template <typename T>
-PyObject *RunReactant(ChemicalReaction *self, T reactant,
+PyObject *RunReactant(ChemicalReaction *self, python::object reactant,
                       unsigned int reactionIdx) {
-  ROMOL_SPTR react = python::extract<ROMOL_SPTR>(reactant);
+  auto react = python::extract<ROMOL_SPTR>(reactant);
 
   std::vector<MOL_SPTR_VECT> mols;
 
@@ -150,7 +159,8 @@ PyObject *RunReactant(ChemicalReaction *self, T reactant,
   return res;
 }
 
-bool RunReactantInPlace(ChemicalReaction *self, ROMol *reactant) {
+bool RunReactantInPlace(ChemicalReaction *self, ROMol *reactant,
+                        bool removeUnmatchedAtoms) {
   auto react = static_cast<RWMol *>(reactant);
   bool res = false;
   {
@@ -158,7 +168,7 @@ bool RunReactantInPlace(ChemicalReaction *self, ROMol *reactant) {
     if (!self->isInitialized()) {
       self->initReactantMatchers();
     }
-    res = self->runReactant(*react);
+    res = self->runReactant(*react, removeUnmatchedAtoms);
   }
   return res;
 }
@@ -302,6 +312,72 @@ ChemicalReaction *ReactionFromSmarts(const char *smarts, python::dict replDict,
   return res;
 }
 
+ChemicalReaction *ReactionFromMrvFile(const char *rxnFilename, bool sanitize,
+                                      bool removeHs) {
+  ChemicalReaction *newR = nullptr;
+  try {
+    newR = MrvFileToChemicalReaction(rxnFilename, sanitize, removeHs);
+  } catch (RDKit::BadFileException &e) {
+    PyErr_SetString(PyExc_IOError, e.what());
+    throw python::error_already_set();
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  return newR;
+}
+
+ChemicalReaction *ReactionFromMrvBlock(python::object imolBlock, bool sanitize,
+                                       bool removeHs) {
+  std::istringstream inStream(pyObjectToString(imolBlock));
+  ChemicalReaction *newR = nullptr;
+  try {
+    newR = MrvDataStreamToChemicalReaction(inStream, sanitize, removeHs);
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  return newR;
+}
+
+python::object ReactionsFromCDXMLFile(const char *filename, bool sanitize,
+                                      bool removeHs) {
+  std::vector<std::unique_ptr<ChemicalReaction>> rxns;
+  try {
+    rxns = CDXMLFileToChemicalReactions(filename, sanitize, removeHs);
+  } catch (RDKit::BadFileException &e) {
+    PyErr_SetString(PyExc_IOError, e.what());
+    throw python::error_already_set();
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  python::list res;
+  for (auto &rxn : rxns) {
+    // take ownership of the data from the unique_ptr
+    res.append(std::shared_ptr<ChemicalReaction>(rxn.release()));
+  }
+  return python::tuple(res);
+}
+
+python::object ReactionsFromCDXMLBlock(python::object imolBlock, bool sanitize,
+                                       bool removeHs) {
+  std::istringstream inStream(pyObjectToString(imolBlock));
+  std::vector<std::unique_ptr<ChemicalReaction>> rxns;
+  try {
+    rxns = CDXMLDataStreamToChemicalReactions(inStream, sanitize, removeHs);
+  } catch (RDKit::FileParseException &e) {
+    BOOST_LOG(rdWarningLog) << e.what() << std::endl;
+  } catch (...) {
+  }
+  python::list res;
+  for (auto &rxn : rxns) {
+    // take ownership of the data from the unique_ptr
+    res.append(std::shared_ptr<ChemicalReaction>(rxn.release()));
+  }
+  return python::tuple(res);
+}
+
 python::object GetReactingAtoms(const ChemicalReaction &self,
                                 bool mappedAtomsOnly) {
   python::list res;
@@ -503,7 +579,8 @@ Sample Usage:
   bool noproxy = true;
   RegisterVectorConverter<RDKit::ROMOL_SPTR>("MOL_SPTR_VECT", noproxy);
 
-  python::class_<RDKit::ChemicalReaction>(
+  python::class_<RDKit::ChemicalReaction,
+                 std::shared_ptr<RDKit::ChemicalReaction>>(
       "ChemicalReaction", docString.c_str(),
       python::init<>("Constructor, takes no arguments"))
       .def(python::init<const std::string &>())
@@ -561,12 +638,11 @@ Sample Usage:
            "the products as a tuple of tuples.  If maxProducts is not zero,"
            " stop the reaction when maxProducts have been generated "
            "[default=1000]")
-      .def("RunReactant",
-           (PyObject * (*)(RDKit::ChemicalReaction *, python::object, unsigned))
-               RDKit::RunReactant,
+      .def("RunReactant", RDKit::RunReactant,
            "apply the reaction to a single reactant")
       .def("RunReactantInPlace", RDKit::RunReactantInPlace,
-           (python::arg("self"), python::arg("reactant")),
+           (python::arg("self"), python::arg("reactant"),
+            python::arg("removeUnmatchedAtoms") = true),
            "apply the reaction to a single reactant in place. The reactant "
            "itself is modified. This can only be used for single reactant - "
            "single product reactions.")
@@ -764,7 +840,8 @@ Sample Usage:
 
       .def("GetPropsAsDict", RDKit::GetPropsAsDict<RDKit::ChemicalReaction>,
            (python::arg("self"), python::arg("includePrivate") = false,
-            python::arg("includeComputed") = false),
+            python::arg("includeComputed") = false,
+            python::arg("autoConvertStrings") = true),
            "Returns a dictionary populated with the reaction's properties.\n"
            " n.b. Some properties are not able to be converted to python "
            "types.\n\n"
@@ -807,15 +884,65 @@ of the replacements argument.",
        python::arg("removeHs") = false, python::arg("strictParsing") = true),
       "construct a ChemicalReaction from a string in MDL rxn format",
       python::return_value_policy<python::manage_new_object>());
+
+  python::def("ReactionFromMrvFile", RDKit::ReactionFromMrvFile,
+              (python::arg("filename"), python::arg("sanitize") = false,
+               python::arg("removeHs") = false),
+              "construct a ChemicalReaction from an Marvin (mrv) rxn file",
+              python::return_value_policy<python::manage_new_object>());
+  python::def(
+      "ReactionFromMrvBlock", RDKit::ReactionFromMrvBlock,
+      (python::arg("rxnblock"), python::arg("sanitize") = false,
+       python::arg("removeHs") = false),
+      "construct a ChemicalReaction from a string in Marvin (mrv) format",
+      python::return_value_policy<python::manage_new_object>());
+
+  python::def(
+      "ReactionFromMrvBlock", RDKit::ReactionFromMrvBlock,
+      (python::arg("rxnblock"), python::arg("sanitize") = false,
+       python::arg("removeHs") = false),
+      "construct a ChemicalReaction from a string in Marvin (mrv) format",
+      python::return_value_policy<python::manage_new_object>());
+
+  python::def("MrvFileIsReaction", RDKit::MrvFileIsReaction,
+              (python::arg("filename")),
+              "returns whether or not an MRV file contains reaction data");
+
+  python::def("MrvBlockIsReaction", RDKit::MrvBlockIsReaction,
+              (python::arg("mrvData")),
+              "returns whether or not an MRV block contains reaction data");
+
+  python::def("ReactionsFromCDXMLFile", RDKit::ReactionsFromCDXMLFile,
+              (python::arg("filename"), python::arg("sanitize") = false,
+               python::arg("removeHs") = false),
+              "construct a tuple of ChemicalReactions from a CDXML rxn file");
+
+  python::def(
+      "ReactionsFromCDXMLBlock", RDKit::ReactionsFromCDXMLBlock,
+      (python::arg("rxnblock"), python::arg("sanitize") = false,
+       python::arg("removeHs") = false),
+      "construct a tuple of ChemicalReactions from a string in CDXML format");
+
   python::def("ReactionToRxnBlock", RDKit::ChemicalReactionToRxnBlock,
               (python::arg("reaction"), python::arg("separateAgents") = false,
                python::arg("forceV3000") = false),
               "construct a string in MDL rxn format for a ChemicalReaction");
+
+  python::def(
+      "ReactionToMrvBlock", RDKit::ChemicalReactionToMrvBlock,
+      (python::arg("reaction"), python::arg("prettyPrint") = false),
+      "construct a string in Marvin (MRV) rxn format for a ChemicalReaction");
+  python::def("ReactionToMrvFile", RDKit::ChemicalReactionToMrvFile,
+              (python::arg("reaction"), python::arg("filename"),
+               python::arg("prettyPrint") = false),
+              "write a Marvin (MRV) rxn file for a ChemicalReaction");
+
   python::def(
       "ReactionToV3KRxnBlock", RDKit::ChemicalReactionToV3KRxnBlock,
       (python::arg("reaction"), python::arg("separateAgents") = false),
       "construct a string in MDL v3000 rxn format for a ChemicalReaction");
 
+#ifdef RDK_USE_BOOST_IOSTREAMS
   python::def("ReactionFromPNGFile", RDKit::PNGFileToChemicalReaction,
               "construct a ChemicalReaction from metadata in a PNG file",
               python::return_value_policy<python::manage_new_object>());
@@ -836,7 +963,7 @@ of the replacements argument.",
        python::arg("includeSmarts") = false, python::arg("includeRxn") = false),
       "Adds metadata about a reaction to the PNG string passed in."
       "The modified string is returned.");
-
+#endif
   python::def("ReactionFromMolecule", RDKit::RxnMolToChemicalReaction,
               "construct a ChemicalReaction from an molecule if the RXN role "
               "property of the molecule is set",
