@@ -67,6 +67,12 @@ RDKIT_GRAPHMOL_EXPORT void assignAtomCIPRanks(const ROMol &mol,
 
 RDKIT_GRAPHMOL_EXPORT bool hasStereoBondDir(const Bond *bond);
 
+// this routine removes chiral markers and stereo indications that should not be
+// present this is only called when the molecule has not been sanitized and when
+// the new stereo (not legacy) is in use
+
+RDKIT_GRAPHMOL_EXPORT void removeBadStereo(ROMol &mol);
+
 /**
  *  Returns the first neighboring bond that can be found which has a stereo
  * bond direction set. If no such bond can be found, it returns null. No
@@ -228,6 +234,8 @@ RDKIT_GRAPHMOL_EXPORT int pickBondToWedge(const Atom *atom, const ROMol &mol,
                                           const INT_VECT &nChiralNbrs,
                                           const INT_MAP_INT &resSoFar,
                                           int noNbrs);
+RDKIT_GRAPHMOL_EXPORT void setStereoanyFromSquiggleBond(ROMol &mol, Bond *bond,
+							Bond::BondStereo stereo=Bond::STEREOANY);
 }  // namespace detail
 
 //! picks the bonds which should be wedged
@@ -241,6 +249,29 @@ RDKIT_GRAPHMOL_EXPORT void wedgeMolBonds(
 RDKIT_GRAPHMOL_EXPORT void wedgeBond(Bond *bond, unsigned int fromAtomIdx,
                                      const Conformer *conf);
 
+//! Returns whether or not a bond is a candidate for bond stereo
+RDKIT_GRAPHMOL_EXPORT bool canBeStereoBond(const Bond *bond);
+
+//! Returns true for double bonds which should be shown as a crossed bonds.
+// It always returns false if any adjacent bond is a squiggle bond.
+RDKIT_GRAPHMOL_EXPORT bool shouldBeACrossedBond(const Bond *bond);
+
+//! Clears existing bond wedging and forces use of atom wedging from MolBlock.
+/*!
+ \param mol: molecule to have its wedges altered
+ */
+RDKIT_GRAPHMOL_EXPORT void reapplyMolBlockWedging(ROMol &mol);
+//! Remove MolBlock bond wedging information from molecule.
+/*!
+ \param mol: molecule to modify
+ */
+RDKIT_GRAPHMOL_EXPORT void clearMolBlockWedgingInfo(ROMol &mol);
+//! Invert bond wedging information read from a mol block (if present).
+/*!
+ \param mol: molecule to modify
+ */
+RDKIT_GRAPHMOL_EXPORT void invertMolBlockWedgingInfo(ROMol &mol);
+
 }  // namespace Chirality
 }  // namespace RDKit
 #endif
