@@ -16,7 +16,9 @@
 #include <GraphMol/RDKitBase.h>
 #include <GraphMol/RWMol.h>
 #include <GraphMol/ROMol.h>
+#include <GraphMol/Substruct/SubstructUtils.h>
 #include <Geometry/Transform2D.h>
+#include <Geometry/Transform3D.h>
 #include <Geometry/point.h>
 #include <queue>
 
@@ -68,8 +70,7 @@ typedef std::list<PAIR_D_I_I> LIST_PAIR_DII;
 
   where A is the angle between a and b
  */
-RDKIT_DEPICTOR_EXPORT RDGeom::INT_POINT2D_MAP embedRing(
-    const RDKit::INT_VECT &ring);
+RDKIT_DEPICTOR_EXPORT RDGeom::INT_POINT2D_MAP embedRing(const RDKit::INT_VECT &ring);
 
 RDKIT_DEPICTOR_EXPORT void transformPoints(RDGeom::INT_POINT2D_MAP &nringCor,
                                            const RDGeom::Transform2D &trans);
@@ -361,6 +362,15 @@ inline int getAtomDepictRank(const RDKit::Atom *at) {
   int deg = at->getDegree();
   return maxDeg * anum + deg;
 }
+
+RDKIT_DEPICTOR_EXPORT bool hasTerminalRGroupOrQueryHydrogen(const RDKit::ROMol &query);
+RDKIT_DEPICTOR_EXPORT std::unique_ptr<RDKit::RWMol> prepareTemplateForRGroups(
+    RDKit::RWMol &templateMol);
+RDKIT_DEPICTOR_EXPORT void reducedToFullMatches(
+    const RDKit::RWMol &reducedQuery, const RDKit::RWMol &molHs,
+    std::vector<RDKit::MatchVectType> &matches);
+RDKIT_DEPICTOR_EXPORT bool invertWedgingIfMolHasFlipped(
+    RDKit::ROMol &mol, const RDGeom::Transform3D &trans);
 }  // namespace RDDepict
 
 #endif
