@@ -102,16 +102,14 @@ unsigned int Compute2DCoordsMimicDistmat(
 }
 
 python::tuple GenerateDepictionMatching2DStructure(
-    RDKit::ROMol &mol, RDKit::ROMol &reference, int confId,
-    python::object refPatt, bool acceptFailure, bool forceRDKit,
-    bool allowRGroups) {
+    RDKit::ROMol &mol, const RDKit::ROMol &reference, int confId,
+    const python::object &refPatt, const ConstrainedDepictionParams &params) {
   RDKit::ROMol *referencePattern = nullptr;
-  if (refPatt != python::object()) {
+  if (!refPatt.is_none()) {
     referencePattern = python::extract<RDKit::ROMol *>(refPatt);
   }
   auto matchVect = RDDepict::generateDepictionMatching2DStructure(
-      mol, reference, confId, referencePattern, acceptFailure, forceRDKit,
-      allowRGroups);
+      mol, reference, confId, referencePattern, params);
   python::list atomMap;
   for (const auto &pair : matchVect) {
     atomMap.append(python::make_tuple(pair.first, pair.second));
@@ -119,14 +117,58 @@ python::tuple GenerateDepictionMatching2DStructure(
   return python::tuple(atomMap);
 }
 
-void GenerateDepictionMatching2DStructureAtomMap(RDKit::ROMol &mol,
-                                                 RDKit::ROMol &reference,
-                                                 python::object atomMap,
-                                                 int confId, bool forceRDKit) {
-  std::unique_ptr<RDKit::MatchVectType> matchVect(translateAtomMap(atomMap));
+python::tuple GenerateDepictionMatching2DStructure(
+    RDKit::ROMol &mol, const RDKit::ROMol &reference, int confId,
+    const python::object &refPatt, bool acceptFailure, bool forceRDKit,
+    bool allowRGroups) {
+  ConstrainedDepictionParams params;
+  params.acceptFailure = acceptFailure;
+  params.forceRDKit = forceRDKit;
+  params.allowRGroups = allowRGroups;
+  return GenerateDepictionMatching2DStructure(mol, reference, confId, refPatt,
+                                              params);
+}
 
+python::tuple GenerateDepictionMatching2DStructure(
+    RDKit::ROMol &mol, const RDKit::ROMol &reference, int confId,
+    const python::object &refPatt, const python::object &pyParams) {
+  ConstrainedDepictionParams params;
+  if (pyParams) {
+    params = python::extract<ConstrainedDepictionParams>(pyParams);
+  }
+  return GenerateDepictionMatching2DStructure(mol, reference, confId, refPatt,
+                                              params);
+}
+
+void GenerateDepictionMatching2DStructureAtomMap(
+    RDKit::ROMol &mol, const RDKit::ROMol &reference,
+    const python::object &atomMap, int confId,
+    const ConstrainedDepictionParams &params) {
+  std::unique_ptr<RDKit::MatchVectType> matchVect(translateAtomMap(atomMap));
   RDDepict::generateDepictionMatching2DStructure(mol, reference, *matchVect,
-                                                 confId, forceRDKit);
+                                                 confId, params);
+}
+
+void GenerateDepictionMatching2DStructureAtomMap(
+    RDKit::ROMol &mol, const RDKit::ROMol &reference,
+    const python::object &atomMap, int confId, const python::object &pyParams) {
+  ConstrainedDepictionParams params;
+  if (pyParams) {
+    params = python::extract<ConstrainedDepictionParams>(pyParams);
+  }
+  GenerateDepictionMatching2DStructureAtomMap(mol, reference, atomMap, confId,
+                                              params);
+}
+
+void GenerateDepictionMatching2DStructureAtomMap(RDKit::ROMol &mol,
+                                                 const RDKit::ROMol &reference,
+                                                 const python::object &atomMap,
+                                                 int confId, bool forceRDKit) {
+  ConstrainedDepictionParams params;
+  params.forceRDKit = forceRDKit;
+
+  GenerateDepictionMatching2DStructureAtomMap(mol, reference, atomMap, confId,
+                                              params);
 }
 
 void GenerateDepictionMatching3DStructure(RDKit::ROMol &mol,
@@ -246,6 +288,45 @@ BOOST_PYTHON_MODULE(rdDepictor) {
       .def("__enter__", &UsingCoordGen::enter)
       .def("__exit__", &UsingCoordGen::exit);
 
+  python::class_<ConstrainedDepictionParams, boost::noncopyable>(
+      "ConstrainedDepictionParams",
+      "Parameters controlling constrained depiction")
+      .def_readwrite(
+          "acceptFailure", &ConstrainedDepictionParams::acceptFailure,
+          "if False (default), a DepictException is thrown if the molecule "
+          "does not have a substructure match to the reference; "
+          "if True, an unconstrained depiction will be generated")
+      .def_readwrite(
+          "forceRDKit", &ConstrainedDepictionParams::forceRDKit,
+          "if True, use RDKit to generate coordinates even if preferCoordGen "
+          "is set to True; defaults to False")
+      .def_readwrite(
+          "allowRGroups", &ConstrainedDepictionParams::allowRGroups,
+          "if True, terminal dummy atoms in the reference are ignored "
+          "if they match an implicit hydrogen in the molecule or if they are "
+          "attached top a query atom; defaults to False")
+      .def_readwrite(
+          "alignOnly", &ConstrainedDepictionParams::alignOnly,
+          "if False (default), a part of the molecule is hard-constrained "
+          "to have the same coordinates as the reference, and the rest of "
+          "the molecule is built around it; if True, coordinates "
+          "from conformation existingConfId are preserved (if they exist) "
+          "or generated without constraints (if they do not exist), then "
+          "the conformation is rigid-body aligned to the reference")
+      .def_readwrite("adjustMolBlockWedging",
+                     &ConstrainedDepictionParams::adjustMolBlockWedging,
+                     "if True (default), existing wedging information "
+                     "will be updated or cleared as required; if False, "
+                     "existing molblock wedging information will "
+                     "always be preserved")
+      .def_readwrite(
+          "existingConfId", &ConstrainedDepictionParams::existingConfId,
+          "conformation id whose 2D coordinates should be "
+          "rigid-body aligned to the reference (if alignOnly is True), "
+          "or used to determine whether existing molblock wedging information "
+          "can be preserved following the constrained depiction (if "
+          "adjustMolBlockWedging is True");
+
   std::string docString;
   docString =
       "Compute 2D coordinates for a molecule. \n\
@@ -323,8 +404,37 @@ BOOST_PYTHON_MODULE(rdDepictor) {
   docString =
       "Generate a depiction for a molecule where a piece of the \n\
   molecule is constrained to have the same coordinates as a reference. \n\n\
-  This is useful for, for example, generating depictions of SAR data \n\
-  sets so that the cores of the molecules are all oriented the same way. \n\
+  The constraint can be hard (default) or soft. \n\
+\n\
+  Hard (default, ConstrainedDepictionParams.alignOnly=False): \n\
+  Existing molecule coordinates, if present, are discarded; \n\
+  new coordinates are generated constraining a piece of the molecule \n\
+  to have the same coordinates as the reference, while the rest of \n\
+  the molecule is built around it. \n\
+  If ConstrainedDepictionParams.adjustMolBlockWedging is False \n\
+  (default), existing molblock wedging information is always preserved. \n\
+  If ConstrainedDepictionParams.adjustMolBlockWedging is True, \n\
+  existing molblock wedging information is preserved in case it \n\
+  only involves the invariant core and the core conformation has not \n\
+  changed, while it is cleared in case the wedging is also outside \n\
+  the invariant core, or core coordinates were changed. \n\
+  If ConstrainedDepictionParams.acceptFailure is set to True and no \n\
+  substructure match is found, coordinates will be recomputed from \n\
+  scratch, hence molblock wedging information will be cleared. \n\
+ \n\
+  Soft (ConstrainedDepictionParams.alignOnly=True): \n\
+  Existing coordinates in the conformation identified by \n\
+  ConstrainedDepictionParams.existingConfId are preserved if present, \n\
+  otherwise unconstrained new coordinates are generated. \n\
+  Subsequently, coodinates undergo a rigid-body alignment to the reference. \n\
+  If ConstrainedDepictionParams.adjustMolBlockWedging is False \n\
+  (default), existing molblock wedging information is always preserved. \n\
+  If ConstrainedDepictionParams.adjustMolBlockWedging is True, \n\
+  existing molblock wedging information is inverted in case the rigid-body \n\
+  alignment involved a flip around the Z axis. \n\
+ \n\
+  This is useful, for example, for generating depictions of SAR data \n\
+  sets such that the cores of the molecules are all oriented the same way. \n\
   ARGUMENTS: \n\n\
   mol -    the molecule to be aligned, this will come back \n\
            with a single conformer. \n\
@@ -333,7 +443,35 @@ BOOST_PYTHON_MODULE(rdDepictor) {
   confId -       (optional) the id of the reference conformation to use \n\
   refPatt -      (optional) a query molecule to be used to generate \n\
                  the atom mapping between the molecule and the reference \n\
-  acceptFailure - (optional) if True, standard depictions will be generated \n\
+  params - (optional) a ConstrainedDepictionParams instance\n\n\
+  RETURNS: a tuple of (refIdx, molIdx) tuples corresponding to the atom \n\
+           indices in mol constrained to have the same coordinates as atom \n\
+           indices in reference.\n";
+  python::def(
+      "GenerateDepictionMatching2DStructure",
+      static_cast<python::tuple (*)(RDKit::ROMol &, const RDKit::ROMol &,
+                                    int confId, const python::object &,
+                                    const python::object &)>(
+          GenerateDepictionMatching2DStructure),
+      (python::arg("mol"), python::arg("reference"), python::arg("confId") = -1,
+       python::arg("refPatt") = python::object(),
+       python::arg("params") = python::object()),
+      docString.c_str());
+
+  docString =
+      "Generate a depiction for a molecule where a piece of the \n\
+  molecule is constrained to have the same coordinates as a reference. \n\n\
+  This is useful, for example, for generating depictions of SAR data \n\
+  sets such that the cores of the molecules are all oriented the same way. \n\
+  ARGUMENTS: \n\n\
+  mol -    the molecule to be aligned, this will come back \n\
+           with a single conformer. \n\
+  reference -    a molecule with the reference atoms to align to; \n\
+                 this should have a depiction. \n\
+  confId -       the id of the reference conformation to use \n\
+  refPatt -      a query molecule to be used to generate \n\
+                 the atom mapping between the molecule and the reference \n\
+  acceptFailure - if True, standard depictions will be generated \n\
                   for molecules that don't have a substructure match to the \n\
                   reference; if False, throws a DepictException.\n\
   forceRDKit -    (optional) use RDKit to generate coordinates even if \n\
@@ -347,7 +485,10 @@ BOOST_PYTHON_MODULE(rdDepictor) {
            indices in reference.\n";
   python::def(
       "GenerateDepictionMatching2DStructure",
-      RDDepict::GenerateDepictionMatching2DStructure,
+      static_cast<python::tuple (*)(RDKit::ROMol &, const RDKit::ROMol &,
+                                    int confId, const python::object &, bool,
+                                    bool, bool)>(
+          GenerateDepictionMatching2DStructure),
       (python::arg("mol"), python::arg("reference"), python::arg("confId") = -1,
        python::arg("refPatt") = python::object(),
        python::arg("acceptFailure") = false, python::arg("forceRDKit") = false,
@@ -366,15 +507,44 @@ BOOST_PYTHON_MODULE(rdDepictor) {
                  this should have a depiction. \n\
   atomMap -      a sequence of (queryAtomIdx, molAtomIdx) pairs that will \n\
                  be used to generate the atom mapping between the molecule \n\
-                 and the reference. \n\
+                 and the reference. Note that this sequence can be shorter \n\
+                 than the number of atoms in the reference.\n\
   confId -       (optional) the id of the reference conformation to use \n\
-  forceRDKit -   (optional) use RDKit to generate coordinates even if \n\
+  params -       (optional) an instance of ConstrainedDepictionParams\n";
+  python::def(
+      "GenerateDepictionMatching2DStructure",
+      static_cast<void (*)(RDKit::ROMol &, const RDKit::ROMol &,
+                           const python::object &, int,
+                           const python::object &)>(
+          RDDepict::GenerateDepictionMatching2DStructureAtomMap),
+      (python::arg("mol"), python::arg("reference"), python::arg("atomMap"),
+       python::arg("confId") = -1, python::arg("params") = python::object()),
+      docString.c_str());
+
+  docString =
+      "Generate a depiction for a molecule where a piece of the \n\
+  molecule is constrained to have the same coordinates as a reference. \n\n\
+  This is useful for, for example, generating depictions of SAR data \n\
+  sets so that the cores of the molecules are all oriented the same way. \n\
+  ARGUMENTS: \n\n\
+  mol -    the molecule to be aligned, this will come back \n\
+           with a single conformer. \n\
+  reference -    a molecule with the reference atoms to align to; \n\
+                 this should have a depiction. \n\
+  atomMap -      a sequence of (queryAtomIdx, molAtomIdx) pairs that will \n\
+                 be used to generate the atom mapping between the molecule \n\
+                 and the reference. Note that this sequence can be shorter \n\
+                 than the number of atoms in the reference.\n\
+  confId -       the id of the reference conformation to use \n\
+  forceRDKit -   use RDKit to generate coordinates even if \n\
                  preferCoordGen is set to true\n";
   python::def(
       "GenerateDepictionMatching2DStructure",
-      RDDepict::GenerateDepictionMatching2DStructureAtomMap,
+      static_cast<void (*)(RDKit::ROMol &, const RDKit::ROMol &,
+                           const python::object &, int, bool)>(
+          RDDepict::GenerateDepictionMatching2DStructureAtomMap),
       (python::arg("mol"), python::arg("reference"), python::arg("atomMap"),
-       python::arg("confId") = -1, python::arg("forceRDKit") = false),
+       python::arg("confId"), python::arg("forceRDKit")),
       docString.c_str());
 
   docString =
