@@ -1,9 +1,7 @@
-# $Id$
-#
-
 import unittest
 from os import environ
 from pathlib import Path
+import re
 
 from rdkit import Chem, DataStructs, RDConfig
 from rdkit.Chem import AllChem, Descriptors
@@ -711,7 +709,7 @@ class TestCase(unittest.TestCase):
       bcut2 = rdMD.BCUT2D(m, "bad_prop")
       self.assertTrue(0, "Failed to handle bad prop (not a double)")
     except RuntimeError as e:
-      self.assertTrue("boost::bad_any_cast" in str(e))
+      self.assertTrue(re.search(r"[B,b]ad any[\ ,_]cast",str(e)))
 
   def testOxidationNumbers(self):
     # majority of tests are in the C++ layer.  These are just to make
