@@ -10,15 +10,21 @@
 
 #include "DetermineBonds.h"
 #include <GraphMol/RDKitBase.h>
+#ifdef RDK_BUILD_YAEHMOP_SUPPORT
 #include <YAeHMOP/EHTTools.h>
+#endif
 #include <iostream>
 #include <vector>
 #include <numeric>
 #include <cmath>
 #include <unordered_map>
+
+#include <RDGeneral/BoostStartInclude.h>
 #include <boost/graph/adjacency_list.hpp>
 #include <boost/graph/max_cardinality_matching.hpp>
 #include <boost/multiprecision/cpp_int.hpp>
+#include <RDGeneral/BoostEndInclude.h>
+#include <GraphMol/FileParsers/ProximityBonds.h>
 
 typedef boost::adjacency_list<boost::vecS, boost::vecS, boost::undirectedS>
     Graph;
@@ -117,6 +123,7 @@ LazyCartesianProduct<unsigned int> getValenceCombinations(
 
 namespace RDKit {
 
+#ifdef RDK_BUILD_YAEHMOP_SUPPORT
 void connectivityHueckel(RWMol &mol, int charge) {
   auto numAtoms = mol.getNumAtoms();
   mol.getAtomWithIdx(0)->setFormalCharge(charge);
@@ -136,6 +143,11 @@ void connectivityHueckel(RWMol &mol, int charge) {
     }
   }
 }  // connectivityHueckel()
+#else
+void connectivityHueckel(RWMol &, int) {
+  CHECK_INVARIANT(0, "YAeHMOP support not available");
+}
+#endif
 
 void connectivityVdW(RWMol &mol, double covFactor) {
   auto numAtoms = mol.getNumAtoms();
@@ -156,7 +168,13 @@ void connectivityVdW(RWMol &mol, double covFactor) {
 }  // connectivityVdW()
 
 void determineConnectivity(RWMol &mol, bool useHueckel, int charge,
-                           double covFactor) {
+                           double covFactor, bool useVdw) {
+#ifndef RDK_BUILD_YAEHMOP_SUPPORT
+  if (useHueckel) {
+    throw ValueErrorException(
+        "The RDKit was not compiled with YAeHMOP support");
+  }
+#endif
   auto numAtoms = mol.getNumAtoms();
   for (unsigned int i = 0; i < numAtoms; i++) {
     for (unsigned int j = i + 1; j < numAtoms; j++) {
@@ -167,8 +185,10 @@ void determineConnectivity(RWMol &mol, bool useHueckel, int charge,
   }
   if (useHueckel) {
     connectivityHueckel(mol, charge);
-  } else {
+  } else if (useVdw) {
     connectivityVdW(mol, covFactor);
+  } else {
+    ConnectTheDots(&mol, ctdIGNORE_H_H_CONTACTS);
   }
 }  // determineConnectivity()
 
@@ -439,11 +459,11 @@ void determineBondOrders(RWMol &mol, int charge, bool allowChargedFragments,
 
 void determineBonds(RWMol &mol, bool useHueckel, int charge, double covFactor,
                     bool allowChargedFragments, bool embedChiral,
-                    bool useAtomMap) {
+                    bool useAtomMap, bool useVdw) {
   if (mol.getNumAtoms() <= 1) {
     return;
   }
-  determineConnectivity(mol, useHueckel, charge, covFactor);
+  determineConnectivity(mol, useHueckel, charge, covFactor, useVdw);
   determineBondOrders(mol, charge, allowChargedFragments, embedChiral,
                       useAtomMap);
 }  // determineBonds()
