@@ -8,7 +8,7 @@
 //
 
 #include <RDGeneral/test.h>
-#include "catch.hpp"
+#include <catch2/catch_all.hpp>
 
 #include <RDGeneral/RDLog.h>
 #include <GraphMol/RDKitBase.h>
@@ -173,7 +173,7 @@ TEST_CASE("update parameters from JSON") {
       auto conf = mol->getConformer();
       auto v1 = conf.getAtomPos(0) - conf.getAtomPos(1);
       auto v2 = conf.getAtomPos(2) - conf.getAtomPos(1);
-      CHECK(v1.angleTo(v2) == Approx(M_PI / 2).margin(0.15));
+      CHECK(v1.angleTo(v2) == Catch::Approx(M_PI / 2).margin(0.15));
     }
   }
 }
@@ -724,4 +724,26 @@ TEST_CASE("Github #6365: cannot generate conformers for PF6- or SF6") {
       CHECK(cid >= 0);
     }
   }
+}
+
+TEST_CASE("Sequential random seeds") {
+  SECTION("basics") {
+    auto mol = "CCCCCCCCCCCC"_smiles;
+    REQUIRE(mol);
+    MolOps::addHs(*mol);
+
+    RWMol mol2(*mol);
+
+    DGeomHelpers::EmbedParameters ps = DGeomHelpers::ETKDGv3;
+    ps.enableSequentialRandomSeeds = true;
+    ps.useRandomCoords = true;
+    ps.randomSeed = 0xf00d;
+    auto cids = DGeomHelpers::EmbedMultipleConfs(*mol, 10, ps);
+    CHECK(cids.size() == 10);
+    ps.randomSeed = 0xf00d + 5;
+    auto cids2 = DGeomHelpers::EmbedMultipleConfs(mol2, 5, ps);
+    CHECK(cids2.size() == 5);
+
+    compareConfs(mol.get(), &mol2, 5, 0);
+  }
 }
\ No newline at end of file
