@@ -14,7 +14,6 @@
 #include <string>
 #include <stdexcept>
 #include "../RDKitBase.h"
-//#include "../Fingerprints/MorganFingerprints.h"
 #include "Graph.h"
 #include "Seed.h"
 #include "DebugTrace.h"  // algorithm filter definitions
@@ -38,15 +37,15 @@ class RDKIT_FMCS_EXPORT SubstructureCache {
 
    public:
     void computeKey(const Seed& seed,
-                    const std::vector<unsigned>& queryAtomLabels,
-                    const std::vector<unsigned>& queryBondLabels) {
+                    const std::vector<unsigned int>& queryAtomLabels,
+                    const std::vector<unsigned int>& queryBondLabels) {
       computeMorganCodeHash(seed, queryAtomLabels, queryBondLabels);
     }
 
    private:
-    void computeMorganCodeHash(const Seed& seed,
-                               const std::vector<unsigned>& queryAtomLabels,
-                               const std::vector<unsigned>& queryBondLabels) {
+    void computeMorganCodeHash(
+        const Seed& seed, const std::vector<unsigned int>& queryAtomLabels,
+        const std::vector<unsigned int>& queryBondLabels) {
       size_t nv = seed.getNumAtoms();
       size_t ne = seed.getNumBonds();
       std::vector<unsigned long> currCodes(nv);
@@ -56,29 +55,29 @@ class RDKIT_FMCS_EXPORT SubstructureCache {
         nIterations = 5;
       }
 
-      for (unsigned seedAtomIdx = 0; seedAtomIdx < seed.getNumAtoms();
-           seedAtomIdx++) {
-        currCodes[seedAtomIdx] =
-            queryAtomLabels[seed.MoleculeFragment.AtomsIdx[seedAtomIdx]];
+      for (unsigned int seedAtomIdx = 0; seedAtomIdx < seed.getNumAtoms();
+           ++seedAtomIdx) {
+        currCodes[seedAtomIdx] = queryAtomLabels.at(
+            seed.MoleculeFragment.Atoms.at(seedAtomIdx)->getIdx());
       }
 
-      for (size_t iter = 0; iter < nIterations; iter++) {
-        for (size_t i = 0; i < nv; i++) {
+      for (size_t iter = 0; iter < nIterations; ++iter) {
+        for (size_t i = 0; i < nv; ++i) {
           prevCodes[i] = currCodes[i];
         }
 
-        for (size_t seedBondIdx = 0; seedBondIdx < ne; seedBondIdx++) {
+        for (size_t seedBondIdx = 0; seedBondIdx < ne; ++seedBondIdx) {
           const Bond* bond = seed.MoleculeFragment.Bonds[seedBondIdx];
-          unsigned order =
-              queryBondLabels[seed.MoleculeFragment.BondsIdx[seedBondIdx]];
-          unsigned atom1 = seed.MoleculeFragment.SeedAtomIdxMap
-                               .find(bond->getBeginAtomIdx())
-                               ->second;
-          unsigned atom2 =
+          unsigned int order = queryBondLabels.at(
+              seed.MoleculeFragment.Bonds.at(seedBondIdx)->getIdx());
+          unsigned int atom1 = seed.MoleculeFragment.SeedAtomIdxMap
+                                   .find(bond->getBeginAtomIdx())
+                                   ->second;
+          unsigned int atom2 =
               seed.MoleculeFragment.SeedAtomIdxMap.find(bond->getEndAtomIdx())
                   ->second;
-          unsigned v1 = prevCodes[atom1];
-          unsigned v2 = prevCodes[atom2];
+          unsigned int v1 = prevCodes[atom1];
+          unsigned int v2 = prevCodes[atom2];
 
           currCodes[atom1] += v2 * v2 + (v2 + 23) * (order + 1721);
           currCodes[atom2] += v1 * v1 + (v1 + 23) * (order + 1721);
@@ -86,7 +85,7 @@ class RDKIT_FMCS_EXPORT SubstructureCache {
       }
 
       KeyNumericMetrics::TValue result = 0;
-      for (unsigned seedAtomIdx = 0; seedAtomIdx < nv; seedAtomIdx++) {
+      for (unsigned int seedAtomIdx = 0; seedAtomIdx < nv; ++seedAtomIdx) {
         unsigned long code = currCodes[seedAtomIdx];
         result += code * (code + 6849) + 29;
       }
@@ -123,12 +122,11 @@ class RDKIT_FMCS_EXPORT SubstructureCache {
   // search algorithm,
   // including a resolving of collisions of hash key
   TIndexEntry* find(const Seed& seed,
-                    const std::vector<unsigned>& queryAtomLabels,
-                    const std::vector<unsigned>& queryBondLabels,
+                    const std::vector<unsigned int>& queryAtomLabels,
+                    const std::vector<unsigned int>& queryBondLabels,
                     TKey& key) {  // compute key and find entry
     key.computeKey(seed, queryAtomLabels, queryBondLabels);
-    std::map<KeyNumericMetrics::TValue, size_t>::const_iterator entryit =
-        NumericIndex.find(key.NumericMetrics.Value);
+    const auto entryit = NumericIndex.find(key.NumericMetrics.Value);
     if (NumericIndex.end() != entryit) {
       return &ValueStorage[entryit->second];
     }
@@ -152,8 +150,8 @@ class RDKIT_FMCS_EXPORT SubstructureCache {
     entry->push_back(seed.Topology);
 
     if (!NumericIndex
-             .insert(std::pair<KeyNumericMetrics::TValue, size_t>(
-                 key.NumericMetrics.Value, ValueStorage.size() - 1))
+             .insert(std::make_pair(key.NumericMetrics.Value,
+                                    ValueStorage.size() - 1))
              .second) {
       return;  // not enough memory room to add the item, but it is just cache
     }
@@ -164,12 +162,9 @@ class RDKIT_FMCS_EXPORT SubstructureCache {
   }
 
   size_t fullsize() const {  // for statistics only
-    size_t n = 0;
-    for (std::vector<TIndexEntry>::const_iterator e = ValueStorage.begin();
-         e != ValueStorage.end(); e++) {
-      n += e->size();
-    }
-    return n;
+    return std::accumulate(
+        ValueStorage.begin(), ValueStorage.end(), 0,
+        [](const auto& acc, const auto& v) { return acc + v.size(); });
   }
 };
 }  // namespace FMCS
