@@ -73,7 +73,7 @@ std::string getSmilesOnly(
     const char* smiles,
     std::string* id = nullptr) {  // remove label, because RDKit parse FAILED
   const char* sp = strchr(smiles, ' ');
-  unsigned n = (sp ? sp - smiles + 1 : strlen(smiles));
+  unsigned int n = (sp ? sp - smiles + 1 : strlen(smiles));
   if (id) {
     *id = std::string(smiles + n);
   }
@@ -105,7 +105,7 @@ std::string getSmilesOnlyChEMBL(
     std::string* id = nullptr) {  // remove label, because RDKit parse FAILED
   const char* sp = strchr(smiles, '\t');
   if (sp) {
-    unsigned n = (sp ? sp - smiles + 1 : strlen(smiles));
+    unsigned int n = (sp ? sp - smiles + 1 : strlen(smiles));
     if (id) {
       *id = std::string(smiles, n);
     }
@@ -121,10 +121,10 @@ std::string getSmilesOnlyChEMBL(
 
 MCSParameters p;
 
-void testFileMCSB(const char* test, unsigned timeout = 30,
-                  std::vector<unsigned> test_N =
-                      std::vector<unsigned>()) {  // optional list of some tests
-                                                  // for investigation
+void testFileMCSB(const char* test, unsigned int timeout = 30,
+                  std::vector<unsigned int> test_N =
+                      std::vector<unsigned int>()) {  // optional list of some
+                                                      // tests for investigation
   p.Verbose = false;
 
   std::vector<ROMOL_SPTR> mols;  // IT CAN OCCUPY A LOT OF MEMORY. store SMILES
@@ -150,7 +150,7 @@ void testFileMCSB(const char* test, unsigned timeout = 30,
 
   std::string outSmilesFile(test);
   outSmilesFile += ".smiles";
-  unsigned n = 0, passed = 0, failed = 0, failed_less = 0, timedout = 0;
+  unsigned int n = 0, passed = 0, failed = 0, failed_less = 0, timedout = 0;
   double secTotal = 0.;
 
   std::vector<MCSResult> referenceResults;
@@ -205,7 +205,7 @@ void testFileMCSB(const char* test, unsigned timeout = 30,
       if ('#' != str[0]) {
         // str= "1 CHEMBL526291 CHEMBL498211 ..."
         char name[256];
-        unsigned nn, len;
+        unsigned int nn, len;
         n++;
         testCase.emplace_back();
         sscanf(str, "%u%n", &nn, &len);
@@ -492,7 +492,7 @@ void test504() {
       "CHEMBL529994",
   };
   RWMol* qm = SmilesToMol(getSmilesOnly(smi[0]));
-  unsigned nq = qm->getNumAtoms();
+  unsigned int nq = qm->getNumAtoms();
   for (size_t ai = 0; ai < nq; ai++) {
     Atom* atom = qm->getAtomWithIdx(ai);
     atom->setProp(common_properties::molAtomMapNumber, (int)ai);
@@ -514,7 +514,7 @@ std::string testChEMBL_Txt(const char* test, double th = 1.0,
   std::cout << "\ntestChEMBL_Txt() " << test << "\n";
   std::vector<ROMOL_SPTR> mols;
   char smiles[4096];
-  // unsigned n=0;
+  // unsigned int n=0;
   FILE* f = fopen(test, "rt");
   if (!f) {
     perror("fopen testChEMBL_Txt()");
@@ -971,7 +971,7 @@ void testChEMBLdat(const char* test, double th = 1.0) {
   std::cout << "\ntestChEMBLdat() " << test << "\n";
   std::vector<ROMOL_SPTR> mols;
   char smiles[4096];
-  unsigned n = 0;
+  unsigned int n = 0;
   FILE* f = fopen(test, "rt");
   if (!f) {
     perror("fopen testChEMBLdat()");
@@ -1208,7 +1208,7 @@ void testFileSDF_RandomSet_SMI(
           "nAtoms;E nBonds;E C++ MCS\n");
 
   bool fileExist = true;
-  unsigned n = 1;
+  unsigned int n = 1;
   for (; fileExist; n++) {
     char smiName[256];
     sprintf(smiName, "%s/smiles/%s.%u.smi", path, test, n);
@@ -1303,7 +1303,7 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
       "ECHO P test;P Nmols;P status;P time,sec;P nAtoms;P nBonds;P MCS >%s\n",
       (std::string(path) + "_" + test + ".P.csv").c_str());
 
-  unsigned n = 1;
+  unsigned int n = 1;
   std::cout
       << "\n****** Load all molecules from SFD and PAIR SET test *********\n\n";
   for (; !suppl->atEnd(); n++) {
@@ -1372,9 +1372,9 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
   delete (suppl);
 
   std::cout << "\n****** RANDOM SET test *********\n\n";
-  const unsigned N_RandomTests = all_mols.size() * 7;
+  const unsigned int N_RandomTests = all_mols.size() * 7;
   srand(1);  // make stable pseudorandom sequence
-  for (unsigned jn = 0; n <= N_RandomTests; jn++, n++) {
+  for (; n <= N_RandomTests; n++) {
     char smiName[256];
     sprintf(smiName, "%s/smilesRAND/%s.%u.smi", path, test, n);
     FILE* fsmi = fopen(smiName, "wt");
@@ -1384,8 +1384,8 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
             (std::string(path) + "_" + test + ".P.csv")
                 .c_str());  // command for the same Python test
     // ROMol *m=0;
-    unsigned iN = 3 + rand() % 32;
-    for (unsigned i = 0; i < iN; i++) {  // load random set
+    unsigned int iN = 3 + rand() % 32;
+    for (unsigned int i = 0; i < iN; i++) {  // load random set
       mols.push_back(all_mols[rand() % (all_mols.size() - 1)]);
       fprintf(fsmi, "%s Mol%u\n", MolToSmiles(*mols.back()).c_str(), n + i);
     }
@@ -1426,16 +1426,16 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
 
   std::cout << "\n****** BIG MCS RANDOM SET test *********\n\n";
 
-  unsigned maxMol = 0;
+  unsigned int maxMol = 0;
   for (auto& all_mol : all_mols) {
     if (maxMol < all_mol->getNumBonds()) {
       maxMol = all_mol->getNumBonds();
     }
   }
-  const unsigned N_BigRandomTests =
+  const unsigned int N_BigRandomTests =
       all_mols.size() > 2000 ? all_mols.size() / 2 : all_mols.size() * 2;
-  const unsigned N_BigRandomTestsAttempts = all_mols.size() * 130;
-  const unsigned SizeOfBigMCS_ForBigRandomTests =
+  const unsigned int N_BigRandomTestsAttempts = all_mols.size() * 130;
+  const unsigned int SizeOfBigMCS_ForBigRandomTests =
       maxMol < 24 ? maxMol * 2 / 3 : 21;
 
   fall = fopen((std::string(path) + "_ALL_BIG.P.bat").c_str(), "at");
@@ -1450,7 +1450,7 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
           "test;Nmols;status;t,sec;nAtoms;nBonds;C++ MCS; E status;E t,sec;E "
           "nAtoms;E nBonds;E C++ MCS\n");
 
-  const unsigned n1 = n;
+  const unsigned int n1 = n;
   fprintf(fcmd, "DEL %s\n",
           (std::string(path) + "_" + test + ".BIG_MCS.P.csv")
               .c_str());  // clear before append results
@@ -1465,11 +1465,11 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
     char smiName[512];
     sprintf(smiName, "%s/smilesBIG/%s.%u.smi", path, test, n);
     // ROMol *m=0;
-    unsigned iN = 2 + rand() % 24;
+    unsigned int iN = 2 + rand() % 24;
     mols.clear();
     for (size_t i = 0; i < iN; i++) {  // load random set
       for (size_t ij = 0; ij < all_mols.size() / 2; ij++) {
-        unsigned mi = rand() % (all_mols.size() - 1);
+        unsigned int mi = rand() % (all_mols.size() - 1);
         if (all_mols[mi]->getNumBonds() < SizeOfBigMCS_ForBigRandomTests) {
           continue;
         }
@@ -1536,7 +1536,7 @@ void testFileSDF_RandomSet(const char* test = "chembl13-10000-random-pairs.sdf",
 void testFileSMILES(const char* test) {
   std::vector<ROMOL_SPTR> mols;
   char smiles[4096];
-  unsigned n = 0;
+  unsigned int n = 0;
   FILE* f = fopen(test, "rt");
   std::cout << "Loading SMILES ... \n";
   while (fgets(smiles, sizeof(smiles), f)) {
@@ -1736,7 +1736,7 @@ int main(int argc, const char* argv[]) {
     //    testGregSDFFileSetFiltered();
     // return 0;
 
-    std::vector<unsigned> tc;
+    std::vector<unsigned int> tc;
     tc.push_back(90);
     tc.push_back(326);
     tc.push_back(330);
@@ -1777,7 +1777,7 @@ int main(int argc, const char* argv[]) {
         fclose(f);
       } break;
       case 'b': {
-        std::vector<unsigned> tc;       // empty -> all
+        std::vector<unsigned int> tc;   // empty -> all
         testFileMCSB(argv[2], 30, tc);  // .mcsb
       } break;
       default:
