@@ -106,10 +106,11 @@ std::unique_ptr<MolSupplier> getSupplier(const std::string& path,
   if (compressionFormat.empty()) {
     strm = new std::ifstream(path.c_str(), std::ios::in | std::ios::binary);
   } else {
-#if RDK_USE_BOOST_IOSTREAMS
+#ifdef RDK_USE_BOOST_IOSTREAMS
     strm = new gzstream(path);
 #else
-    throw BadFileException("Unsupported fileFormat: " + fileFormat);
+    throw BadFileException(
+        "compressed files are only supported if the RDKit is built with boost::iostreams support");
 #endif
   }
 
@@ -162,7 +163,7 @@ std::unique_ptr<MolSupplier> getSupplier(const std::string& path,
     std::unique_ptr<MolSupplier> p(tdtsup);
     return p;
   }
-  throw BadFileException("Unsupported fileFormat: " + fileFormat);
+  throw BadFileException("Unsupported file format: " + fileFormat);
 }
 
 }  // namespace GeneralMolSupplier
