@@ -194,7 +194,6 @@ ROMol *MultithreadedSmilesMolSupplier::processMoleculeRecord(
   // -----------
   // read in the properties
   // -----------
-  unsigned int iprop = 0;
   for (unsigned int col = 0; col < recs.size(); col++) {
     if (static_cast<int>(col) == d_smi || static_cast<int>(col) == d_name) {
       continue;
@@ -211,7 +210,6 @@ ROMol *MultithreadedSmilesMolSupplier::processMoleculeRecord(
 
     pval = recs[col];
     res->setProp(pname, pval);
-    iprop++;
   }
   return res;
 }
