@@ -7,8 +7,8 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
-#include <string.h>
-#include <stdio.h>
+#include <cstring>
+#include <cstdio>
 #include <string>
 #include <iostream>
 #include <fstream>
@@ -30,7 +30,11 @@
 // flavor & 2 : Read each MODEL into a separate molecule.
 namespace RDKit {
 
-static Atom *PDBAtomFromSymbol(const char *symb) {
+namespace {
+
+constexpr int BCNAM(char A, char B, char C) { return (A << 16) | (B << 8) | C; }
+
+Atom *PDBAtomFromSymbol(const char *symb) {
   PRECONDITION(symb, "bad char ptr");
   if (symb[0] == 'D' && !symb[1]) {
     auto *result = new Atom(1);
@@ -45,23 +49,33 @@ static Atom *PDBAtomFromSymbol(const char *symb) {
   return elemno > 0 ? new Atom(elemno) : (Atom *)nullptr;
 }
 
-static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
-                        unsigned int flavor, std::map<int, Atom *> &amap) {
+void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
+                 unsigned int flavor, std::map<int, Atom *> &amap) {
   PRECONDITION(mol, "bad mol");
   PRECONDITION(ptr, "bad char ptr");
   std::string tmp;
 
-  if (len < 16) return;
+  if (len < 16) {
+    return;
+  }
 
   if ((flavor & 1) == 0) {
     // Ignore alternate locations of atoms.
-    if (len >= 17 && ptr[16] != ' ' && ptr[16] != 'A' && ptr[16] != '1') return;
+    if (len >= 17 && ptr[16] != ' ' && ptr[16] != 'A' && ptr[16] != '1') {
+      return;
+    }
     // Ignore XPLOR pseudo atoms
-    if (len >= 54 && !memcmp(ptr + 30, "9999.0009999.0009999.000", 24)) return;
+    if (len >= 54 && !memcmp(ptr + 30, "9999.0009999.0009999.000", 24)) {
+      return;
+    }
     // Ignore NMR pseudo atoms
-    if (ptr[12] == ' ' && ptr[13] == 'Q') return;
+    if (ptr[12] == ' ' && ptr[13] == 'Q') {
+      return;
+    }
     // Ignore PDB dummy residues
-    if (len >= 20 && !memcmp(ptr + 18, "DUM", 3)) return;
+    if (len >= 20 && !memcmp(ptr + 18, "DUM", 3)) {
+      return;
+    }
   }
 
   int serialno;
@@ -87,23 +101,29 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
       } else if (ptr[77] >= 'a' && ptr[77] <= 'z') {
         symb[1] = ptr[77];
         symb[2] = '\0';
-      } else
+      } else {
         symb[1] = '\0';
+      }
     } else if (ptr[76] == ' ' && ptr[77] >= 'A' && ptr[77] <= 'Z') {
       symb[0] = ptr[77];
       symb[1] = '\0';
-    } else
+    } else {
       symb[0] = '\0';
+    }
   } else if (len == 77) {
     if (ptr[76] >= 'A' && ptr[76] <= 'Z') {
       symb[0] = ptr[76];
       symb[1] = '\0';
-    } else
+    } else {
       symb[0] = '\0';
-  } else
+    }
+  } else {
     symb[0] = '\0';
+  }
 
-  if (symb[0]) atom = PDBAtomFromSymbol(symb);
+  if (symb[0]) {
+    atom = PDBAtomFromSymbol(symb);
+  }
 
   if (!atom) {
     // Attempt #2: Atomic Symbol from PDB atom name
@@ -113,8 +133,9 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
         if (ptr[14] >= 'a' && ptr[14] <= 'z') {
           symb[1] = ptr[14];
           symb[2] = '\0';
-        } else
+        } else {
           symb[1] = '\0';
+        }
       } else if (ptr[12] >= 'A' && ptr[12] <= 'Z') {
         symb[0] = ptr[12];
         symb[1] = ptr[13] + 32;  // tolower
@@ -127,12 +148,16 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
       } else if (ptr[12] >= '0' && ptr[12] <= '9') {
         symb[0] = ptr[13];
         symb[1] = '\0';
-      } else
+      } else {
         symb[0] = '\0';
-    } else
+      }
+    } else {
       symb[0] = '\0';
+    }
 
-    if (symb[0]) atom = PDBAtomFromSymbol(symb);
+    if (symb[0]) {
+      atom = PDBAtomFromSymbol(symb);
+    }
   }
 
   if (!atom) {
@@ -148,10 +173,12 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
     RDGeom::Point3D pos;
     try {
       pos.x = FileParserUtils::toDouble(std::string(ptr + 30, 8));
-      if (len >= 46)
+      if (len >= 46) {
         pos.y = FileParserUtils::toDouble(std::string(ptr + 38, 8));
-      if (len >= 54)
+      }
+      if (len >= 54) {
         pos.z = FileParserUtils::toDouble(std::string(ptr + 46, 8));
+      }
     } catch (boost::bad_lexical_cast &) {
       std::ostringstream errout;
       errout << "Problem with coordinates for PDB atom #" << serialno;
@@ -166,7 +193,9 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
       mol->addConformer(conf, false);
     } else {
       conf = &mol->getConformer();
-      if (pos.z != 0.0) conf->set3D(true);
+      if (pos.z != 0.0) {
+        conf->set3D(true);
+      }
     }
     conf->setAtomPos(atom->getIdx(), pos);
   }
@@ -174,33 +203,39 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
   if (len >= 79) {
     int charge = 0;
     if (ptr[78] >= '1' && ptr[78] <= '9') {
-      if (ptr[79] == '-')
+      if (ptr[79] == '-') {
         charge = -(ptr[78] - '0');
-      else if (ptr[79] == '+' || ptr[79] == ' ' || !ptr[79])
+      } else if (ptr[79] == '+' || ptr[79] == ' ' || !ptr[79]) {
         charge = ptr[78] - '0';
+      }
     } else if (ptr[78] == '+') {
-      if (ptr[79] >= '1' && ptr[79] <= '9')
+      if (ptr[79] >= '1' && ptr[79] <= '9') {
         charge = ptr[79] - '0';
-      else if (ptr[79] == '+')
+      } else if (ptr[79] == '+') {
         charge = 2;
-      else if (ptr[79] != '0')
+      } else if (ptr[79] != '0') {
         charge = 1;
+      }
     } else if (ptr[78] == '-') {
-      if (ptr[79] >= '1' && ptr[79] <= '9')
+      if (ptr[79] >= '1' && ptr[79] <= '9') {
         charge = ptr[79] - '0';
-      else if (ptr[79] == '-')
+      } else if (ptr[79] == '-') {
         charge = -2;
-      else if (ptr[79] != '0')
+      } else if (ptr[79] != '0') {
         charge = -1;
+      }
     } else if (ptr[78] == ' ') {
-      if (ptr[79] >= '1' && ptr[79] <= '9')
+      if (ptr[79] >= '1' && ptr[79] <= '9') {
         charge = ptr[79] - '0';
-      else if (ptr[79] == '+')
+      } else if (ptr[79] == '+') {
         charge = 1;
-      else if (ptr[79] == '-')
+      } else if (ptr[79] == '-') {
         charge = -1;
+      }
+    }
+    if (charge != 0) {
+      atom->setFormalCharge(charge);
     }
-    if (charge != 0) atom->setFormalCharge(charge);
   }
 
   tmp = std::string(ptr + 12, 4);
@@ -210,24 +245,30 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
   if (len >= 20) {
     tmp = std::string(ptr + 17, 3);
     // boost::trim(tmp);
-  } else
+  } else {
     tmp = "UNL";
+  }
   info->setResidueName(tmp);
-  if (ptr[0] == 'H') info->setIsHeteroAtom(true);
-  if (len >= 17)
+  if (ptr[0] == 'H') {
+    info->setIsHeteroAtom(true);
+  }
+  if (len >= 17) {
     tmp = std::string(ptr + 16, 1);
-  else
+  } else {
     tmp = " ";
+  }
   info->setAltLoc(tmp);
-  if (len >= 22)
+  if (len >= 22) {
     tmp = std::string(ptr + 21, 1);
-  else
+  } else {
     tmp = " ";
+  }
   info->setChainId(tmp);
-  if (len >= 27)
+  if (len >= 27) {
     tmp = std::string(ptr + 26, 1);
-  else
+  } else {
     tmp = " ";
+  }
   info->setInsertionCode(tmp);
 
   int resno = 1;
@@ -267,13 +308,14 @@ static void PDBAtomLine(RWMol *mol, const char *ptr, unsigned int len,
   info->setTempFactor(bfactor);
 }
 
-static void PDBBondLine(RWMol *mol, const char *ptr, unsigned int len,
-                        std::map<int, Atom *> &amap,
-                        std::map<Bond *, int> &bmap) {
+void PDBBondLine(RWMol *mol, const char *ptr, unsigned int len,
+                 std::map<int, Atom *> &amap, std::map<Bond *, int> &bmap) {
   PRECONDITION(mol, "bad mol");
   PRECONDITION(ptr, "bad char ptr");
 
-  if (len < 16) return;
+  if (len < 16) {
+    return;
+  }
 
   std::string tmp(ptr + 6, 5);
   bool fail = false;
@@ -281,18 +323,26 @@ static void PDBBondLine(RWMol *mol, const char *ptr, unsigned int len,
 
   try {
     src = FileParserUtils::toInt(tmp);
-    if (amap.find(src) == amap.end()) return;
+    if (amap.find(src) == amap.end()) {
+      return;
+    }
   } catch (boost::bad_lexical_cast &) {
     fail = true;
   }
 
   if (!fail) {
-    if (len > 41) len = 41;
+    if (len > 41) {
+      len = 41;
+    }
     for (unsigned int pos = 11; pos + 5 <= len; pos += 5) {
-      if (!memcmp(ptr + pos, "     ", 5)) break;
+      if (!memcmp(ptr + pos, "     ", 5)) {
+        break;
+      }
       try {
         dst = FileParserUtils::toInt(std::string(ptr + pos, 5));
-        if (dst == src || amap.find(dst) == amap.end()) continue;
+        if (dst == src || amap.find(dst) == amap.end()) {
+          continue;
+        }
       } catch (boost::bad_lexical_cast &) {
         fail = true;
       }
@@ -307,42 +357,57 @@ static void PDBBondLine(RWMol *mol, const char *ptr, unsigned int len,
           if (src < dst) {
             if ((seen & 0x0f) == 0x01) {
               bmap[bond] = seen | 0x02;
-              if ((seen & 0x20) == 0) bond->setBondType(Bond::DOUBLE);
+              if ((seen & 0x20) == 0) {
+                bond->setBondType(Bond::DOUBLE);
+              }
             } else if ((seen & 0x0f) == 0x03) {
               bmap[bond] = seen | 0x04;
-              if ((seen & 0x40) == 0) bond->setBondType(Bond::TRIPLE);
+              if ((seen & 0x40) == 0) {
+                bond->setBondType(Bond::TRIPLE);
+              }
             } else if ((seen & 0x0f) == 0x07) {
               bmap[bond] = seen | 0x08;
-              if ((seen & 0x80) == 0) bond->setBondType(Bond::QUADRUPLE);
+              if ((seen & 0x80) == 0) {
+                bond->setBondType(Bond::QUADRUPLE);
+              }
             }
           } else /* src < dst */ {
             if ((seen & 0xf0) == 0x10) {
               bmap[bond] = seen | 0x20;
-              if ((seen & 0x02) == 0) bond->setBondType(Bond::DOUBLE);
+              if ((seen & 0x02) == 0) {
+                bond->setBondType(Bond::DOUBLE);
+              }
             } else if ((seen & 0xf0) == 0x30) {
               bmap[bond] = seen | 0x40;
-              if ((seen & 0x04) == 0) bond->setBondType(Bond::TRIPLE);
+              if ((seen & 0x04) == 0) {
+                bond->setBondType(Bond::TRIPLE);
+              }
             } else if ((seen & 0xf0) == 0x70) {
               bmap[bond] = seen | 0x80;
-              if ((seen & 0x08) == 0) bond->setBondType(Bond::QUADRUPLE);
+              if ((seen & 0x08) == 0) {
+                bond->setBondType(Bond::QUADRUPLE);
+              }
             }
           }
         } else if (!bond) {
           // Bonds in PDB file are explicit
           // if they are not sanitize friendly, set their order to zero
-          if (IsBlacklistedPair(amap[src], amap[dst]))
+          if (IsBlacklistedPair(amap[src], amap[dst])) {
             bond = new Bond(Bond::ZERO);
-          else
+          } else {
             bond = new Bond(Bond::SINGLE);
+          }
           bond->setOwningMol(mol);
           bond->setBeginAtom(amap[src]);
           bond->setEndAtom(amap[dst]);
           mol->addBond(bond, true);
           bmap[bond] = (src < dst) ? 0x01 : 0x10;
-        } else
+        } else {
           break;
-      } else
+        }
+      } else {
         break;
+      }
     }
   }
 
@@ -353,21 +418,28 @@ static void PDBBondLine(RWMol *mol, const char *ptr, unsigned int len,
   }
 }
 
-static void PDBTitleLine(RWMol *mol, const char *ptr, unsigned int len) {
+void PDBTitleLine(RWMol *mol, const char *ptr, unsigned int len) {
   PRECONDITION(mol, "bad mol");
   PRECONDITION(ptr, "bad char ptr");
   std::string title;
-  while (ptr[len - 1] == ' ') len--;
-  if (ptr[len - 1] == ';') len--;
-  if (len > 21 && !strncmp(ptr + 10, " MOLECULE: ", 11))
+  while (ptr[len - 1] == ' ') {
+    len--;
+  }
+  if (ptr[len - 1] == ';') {
+    len--;
+  }
+  if (len > 21 && !strncmp(ptr + 10, " MOLECULE: ", 11)) {
     title = std::string(ptr + 21, len - 21);
-  else if (len > 10)
+  } else if (len > 10) {
     title = std::string(ptr + 10, len - 10);
-  if (!title.empty()) mol->setProp(common_properties::_Name, title);
+  }
+  if (!title.empty()) {
+    mol->setProp(common_properties::_Name, title);
+  }
 }
 
-static void PDBConformerLine(RWMol *mol, const char *ptr, unsigned int len,
-                             Conformer *&conf, int &conformer_atmidx) {
+void PDBConformerLine(RWMol *mol, const char *ptr, unsigned int len,
+                      Conformer *&conf, int &conformer_atmidx) {
   PRECONDITION(mol, "bad mol");
   PRECONDITION(ptr, "bad char ptr");
 
@@ -375,10 +447,12 @@ static void PDBConformerLine(RWMol *mol, const char *ptr, unsigned int len,
     RDGeom::Point3D pos;
     try {
       pos.x = FileParserUtils::toDouble(std::string(ptr + 30, 8));
-      if (len >= 46)
+      if (len >= 46) {
         pos.y = FileParserUtils::toDouble(std::string(ptr + 38, 8));
-      if (len >= 54)
+      }
+      if (len >= 54) {
         pos.z = FileParserUtils::toDouble(std::string(ptr + 46, 8));
+      }
     } catch (boost::bad_lexical_cast &) {
       std::ostringstream errout;
       errout << "Problem with multi-conformer coordinates";
@@ -390,8 +464,9 @@ static void PDBConformerLine(RWMol *mol, const char *ptr, unsigned int len,
       conf->setId(mol->getNumConformers());
       conf->set3D(pos.z != 0.0);
       mol->addConformer(conf, false);
-    } else if (pos.z != 0.0)
+    } else if (pos.z != 0.0) {
       conf->set3D(true);
+    }
 
     if (conformer_atmidx < rdcast<int>(mol->getNumAtoms())) {
       conf->setAtomPos(conformer_atmidx, pos);
@@ -400,13 +475,10 @@ static void PDBConformerLine(RWMol *mol, const char *ptr, unsigned int len,
   }
 }
 
-// This is a macro to allow its use for C++ constants
-#define BCNAM(A, B, C) (((A) << 16) | ((B) << 8) | (C))
-
 // This function determines whether a standard atom name in
 // in a recognized PDB amino acid should be chiral or not.
 // This is used to avoid chirality on VAL.CG and LEU.CG.
-static bool StandardPDBChiralAtom(const char *resnam, const char *atmnam) {
+bool StandardPDBChiralAtom(const char *resnam, const char *atmnam) {
   switch (BCNAM(resnam[0], resnam[1], resnam[2])) {
     case BCNAM('G', 'L', 'Y'):
       return false;
@@ -438,19 +510,20 @@ static bool StandardPDBChiralAtom(const char *resnam, const char *atmnam) {
   return false;
 }
 
-static void StandardPDBResidueChirality(RWMol *mol) {
+void StandardPDBResidueChirality(RWMol *mol) {
   for (ROMol::AtomIterator atomIt = mol->beginAtoms();
        atomIt != mol->endAtoms(); ++atomIt) {
     Atom *atom = *atomIt;
     if (atom->getChiralTag() != Atom::CHI_UNSPECIFIED) {
-      AtomPDBResidueInfo *info = (AtomPDBResidueInfo *)atom->getMonomerInfo();
+      auto *info = (AtomPDBResidueInfo *)atom->getMonomerInfo();
       if (info && info->getMonomerType() == AtomMonomerInfo::PDBRESIDUE &&
           !info->getIsHeteroAtom() &&
           !StandardPDBChiralAtom(info->getResidueName().c_str(),
                                  info->getName().c_str())) {
         atom->setChiralTag(Atom::CHI_UNSPECIFIED);
-        if (atom->hasProp(common_properties::_CIPCode))
+        if (atom->hasProp(common_properties::_CIPCode)) {
           atom->clearProp(common_properties::_CIPCode);
+        }
       }
     }
   }
@@ -473,12 +546,11 @@ void BasicPDBCleanup(RWMol &mol) {
   }
 }
 
-RWMol *PDBBlockToMol(const char *str, bool sanitize, bool removeHs,
-                     unsigned int flavor, bool proximityBonding) {
+void parsePdbBlock(RWMol *&mol, const char *str, bool sanitize, bool removeHs,
+                   unsigned int flavor, bool proximityBonding) {
   PRECONDITION(str, "bad char ptr");
   std::map<int, Atom *> amap;
   std::map<Bond *, int> bmap;
-  RWMol *mol = nullptr;
   Utils::LocaleSwitcher ls;
   bool multi_conformer = false;
   int conformer_atmidx = 0;
@@ -492,8 +564,9 @@ RWMol *PDBBlockToMol(const char *str, bool sanitize, bool removeHs,
         len = (unsigned int)(next - str);
         if (next[1] == '\n') {
           next += 2;
-        } else
+        } else {
           next++;
+        }
         break;
       } else if (*next == '\n') {
         len = (unsigned int)(next - str);
@@ -510,37 +583,53 @@ RWMol *PDBBlockToMol(const char *str, bool sanitize, bool removeHs,
     if (str[0] == 'A' && str[1] == 'T' && str[2] == 'O' && str[3] == 'M' &&
         str[4] == ' ' && str[5] == ' ') {
       if (!multi_conformer) {
-        if (!mol) mol = new RWMol();
+        if (!mol) {
+          mol = new RWMol();
+        }
         PDBAtomLine(mol, str, len, flavor, amap);
-      } else
+      } else {
         PDBConformerLine(mol, str, len, conf, conformer_atmidx);
+      }
       // HETATM records
     } else if (str[0] == 'H' && str[1] == 'E' && str[2] == 'T' &&
                str[3] == 'A' && str[4] == 'T' && str[5] == 'M') {
       if (!multi_conformer) {
-        if (!mol) mol = new RWMol();
+        if (!mol) {
+          mol = new RWMol();
+        }
         PDBAtomLine(mol, str, len, flavor, amap);
-      } else
+      } else {
         PDBConformerLine(mol, str, len, conf, conformer_atmidx);
+      }
       // CONECT records
     } else if (str[0] == 'C' && str[1] == 'O' && str[2] == 'N' &&
                str[3] == 'E' && str[4] == 'C' && str[5] == 'T') {
-      if (mol && !multi_conformer) PDBBondLine(mol, str, len, amap, bmap);
+      if (mol && !multi_conformer) {
+        PDBBondLine(mol, str, len, amap, bmap);
+      }
       // COMPND records
     } else if (str[0] == 'C' && str[1] == 'O' && str[2] == 'M' &&
                str[3] == 'P' && str[4] == 'N' && str[5] == 'D') {
-      if (!mol) mol = new RWMol();
-      if (len > 10 && (str[9] == ' ' || !strncmp(str + 9, "2 MOLECULE: ", 12)))
+      if (!mol) {
+        mol = new RWMol();
+      }
+      if (len > 10 &&
+          (str[9] == ' ' || !strncmp(str + 9, "2 MOLECULE: ", 12))) {
         PDBTitleLine(mol, str, len);
+      }
       // HEADER records
     } else if (str[0] == 'H' && str[1] == 'E' && str[2] == 'A' &&
                str[3] == 'D' && str[4] == 'E' && str[5] == 'R') {
-      if (!mol) mol = new RWMol();
+      if (!mol) {
+        mol = new RWMol();
+      }
       PDBTitleLine(mol, str, len < 50 ? len : 50);
       // ENDMDL records
     } else if (str[0] == 'E' && str[1] == 'N' && str[2] == 'D' &&
                str[3] == 'M' && str[4] == 'D' && str[5] == 'L') {
-      if (!mol) break;
+      if (!mol) {
+        break;
+      }
       multi_conformer = true;
       conformer_atmidx = 0;
       conf = nullptr;
@@ -548,12 +637,17 @@ RWMol *PDBBlockToMol(const char *str, bool sanitize, bool removeHs,
     str = next;
   }
 
-  if (!mol) return (RWMol *)nullptr;
+  if (!mol) {
+    return;
+  }
 
-  if (proximityBonding) ConnectTheDots(mol, ctdIGNORE_H_H_CONTACTS);
+  if (proximityBonding) {
+    ConnectTheDots(mol, ctdIGNORE_H_H_CONTACTS);
+  }
   // flavor & 8 doesn't encode double bonds
-  if (proximityBonding || ((flavor & 8) != 0))
+  if (proximityBonding || flavor & 8) {
     StandardPDBResidueBondOrders(mol);
+  }
 
   BasicPDBCleanup(*mol);
 
@@ -571,6 +665,18 @@ RWMol *PDBBlockToMol(const char *str, bool sanitize, bool removeHs,
   /* Set tetrahedral chirality from 3D co-ordinates */
   MolOps::assignChiralTypesFrom3D(*mol);
   StandardPDBResidueChirality(mol);
+}
+}  // namespace
+
+RWMol *PDBBlockToMol(const char *str, bool sanitize, bool removeHs,
+                     unsigned int flavor, bool proximityBonding) {
+  RWMol *mol = nullptr;
+  try {
+    parsePdbBlock(mol, str, sanitize, removeHs, flavor, proximityBonding);
+  } catch (...) {
+    delete mol;
+    throw;
+  }
 
   return mol;
 }
@@ -593,12 +699,14 @@ RWMol *PDBDataStreamToMol(std::istream *inStream, bool sanitize, bool removeHs,
     auto ptr = line.c_str();
     // Check for END
     if (ptr[0] == 'E' && ptr[1] == 'N' && ptr[2] == 'D' &&
-        (ptr[3] == ' ' || ptr[3] == '\r' || ptr[3] == '\n' || !ptr[3]))
+        (ptr[3] == ' ' || ptr[3] == '\r' || ptr[3] == '\n' || !ptr[3])) {
       break;
+    }
     // Check for ENDMDL
     if ((flavor & 2) != 0 && ptr[0] == 'E' && ptr[1] == 'N' && ptr[2] == 'D' &&
-        ptr[3] == 'M' && ptr[4] == 'D' && ptr[5] == 'L')
+        ptr[3] == 'M' && ptr[4] == 'D' && ptr[5] == 'L') {
       break;
+    }
   }
   return PDBBlockToMol(buffer.c_str(), sanitize, removeHs, flavor,
                        proximityBonding);
