@@ -112,11 +112,6 @@ void TDTMolSupplier::init() {
   d_last = 0;
   d_line = 0;
 }
-TDTMolSupplier::~TDTMolSupplier() {
-  if (df_owner && dp_inStream) {
-    delete dp_inStream;
-  }
-}
 
 void TDTMolSupplier::setData(const std::string &text,
                              const std::string &nameRecord, int confId2D,
