@@ -18,7 +18,7 @@ class ROMol;
 namespace ForceFieldsHelper {
 namespace detail {
 #ifdef RDK_BUILD_THREADSAFE_SSS
-void OptimizeMoleculeConfsHelper_(ForceFields::ForceField ff, ROMol *mol,
+inline void OptimizeMoleculeConfsHelper_(ForceFields::ForceField ff, ROMol *mol,
                                   std::vector<std::pair<int, double>> *res,
                                   unsigned int threadIdx,
                                   unsigned int numThreads, int maxIters) {
@@ -43,7 +43,7 @@ void OptimizeMoleculeConfsHelper_(ForceFields::ForceField ff, ROMol *mol,
   }
 }
 
-void OptimizeMoleculeConfsMT(ROMol &mol, const ForceFields::ForceField &ff,
+inline void OptimizeMoleculeConfsMT(ROMol &mol, const ForceFields::ForceField &ff,
                              std::vector<std::pair<int, double>> &res,
                              int numThreads, int maxIters) {
   std::vector<std::thread> tg;
@@ -59,7 +59,7 @@ void OptimizeMoleculeConfsMT(ROMol &mol, const ForceFields::ForceField &ff,
 }
 #endif
 
-void OptimizeMoleculeConfsST(ROMol &mol, ForceFields::ForceField &ff,
+inline void OptimizeMoleculeConfsST(ROMol &mol, ForceFields::ForceField &ff,
                              std::vector<std::pair<int, double>> &res,
                              int maxIters) {
   PRECONDITION(res.size() >= mol.getNumConformers(),
@@ -90,7 +90,7 @@ void OptimizeMoleculeConfsST(ROMol &mol, ForceFields::ForceField &ff,
   more iterations are required.
      second: the energy
 */
-std::pair<int, double> OptimizeMolecule(ForceFields::ForceField &ff,
+inline std::pair<int, double> OptimizeMolecule(ForceFields::ForceField &ff,
                                         int maxIters = 1000) {
   ff.initialize();
   int res = ff.minimize(maxIters);
@@ -111,7 +111,7 @@ std::pair<int, double> OptimizeMolecule(ForceFields::ForceField &ff,
   \param maxIters   the maximum number of force-field iterations
 
 */
-void OptimizeMoleculeConfs(ROMol &mol, ForceFields::ForceField &ff,
+inline void OptimizeMoleculeConfs(ROMol &mol, ForceFields::ForceField &ff,
                            std::vector<std::pair<int, double>> &res,
                            int numThreads = 1, int maxIters = 1000) {
   res.resize(mol.getNumConformers());
