@@ -49,6 +49,7 @@
 #include <iostream>
 #include <RDGeneral/RDLog.h>
 #include <RDGeneral/utils.h>
+#include <GraphMol/Chirality.h>
 #include "../RDKitBase.h"
 #include "../FileParsers/FileParsers.h"  //MOL single molecule !
 #include "../FileParsers/MolSupplier.h"  //SDF
@@ -690,6 +691,14 @@ std::endl;
 //====================================================================================================
 //====================================================================================================
 
+void testGithub6900 () {
+  RDKit::Chirality::setUseLegacyStereoPerception(false);
+  //auto mol = "CN1CCCN=C1/C=C/c1cccs1"_smiles;
+  auto mol = "N/C=C/C"_smiles;
+  std::vector<std::pair<ROMOL_SPTR, ROMOL_SPTR>> res;
+  RDKit::MMPA::fragmentMol(*mol, res, 3);
+  RDKit::Chirality::setUseLegacyStereoPerception(true);
+}
 int main() {
   BOOST_LOG(rdInfoLog)
       << "*******************************************************\n";
@@ -703,7 +712,7 @@ int main() {
 #else
   setpriority(PRIO_PROCESS, getpid(), -20);
 #endif
-
+  testGithub6900();
   T0 = nanoClock();
   t0 = nanoClock();
 
@@ -711,6 +720,7 @@ int main() {
   // /*
   test2();
   test3();
+    
   //    test4();
   // */
   //    debugTest1("C[*:1].O=C(NCCO)c1c([*:1])n([O-])c2ccccc2[n+]1=O");
