@@ -212,6 +212,21 @@ void MolDraw2DSVG::drawWavyLine(const Point2D &cds1, const Point2D &cds2,
   d_os << " />\n";
 }
 
+namespace {
+std::string getDashString(const DashPattern &dashes) {
+  std::string res;
+  if (dashes.size()) {
+    std::stringstream dss;
+    dss << ";stroke-dasharray:";
+    std::copy(dashes.begin(), dashes.end() - 1,
+              std::ostream_iterator<double>(dss, ","));
+    dss << dashes.back();
+    res = dss.str();
+  }
+  return res;
+}
+}  // namespace
+
 // ****************************************************************************
 void MolDraw2DSVG::drawLine(const Point2D &cds1, const Point2D &cds2,
                             bool rawCoords) {
@@ -219,16 +234,7 @@ void MolDraw2DSVG::drawLine(const Point2D &cds1, const Point2D &cds2,
   Point2D c2 = rawCoords ? cds2 : getDrawCoords(cds2);
   std::string col = DrawColourToSVG(colour());
   double width = getDrawLineWidth();
-  std::string dashString = "";
-  const DashPattern &dashes = dash();
-  if (dashes.size()) {
-    std::stringstream dss;
-    dss << ";stroke-dasharray:";
-    std::copy(dashes.begin(), dashes.end() - 1,
-              std::ostream_iterator<double>(dss, ","));
-    dss << dashes.back();
-    dashString = dss.str();
-  }
+  std::string dashString = getDashString(dash());
   d_os << "<path ";
   outputClasses();
   d_os << "d='M " << MolDraw2D_detail::formatDouble(c1.x) << ","
@@ -249,7 +255,8 @@ void MolDraw2DSVG::drawPolygon(const std::vector<Point2D> &cds,
 
   std::string col = DrawColourToSVG(colour());
   double width = getDrawLineWidth();
-  std::string dashString = "";
+  std::string dashString = getDashString(dash());
+
   d_os << "<path ";
   outputClasses();
   d_os << "d='M";
@@ -290,7 +297,7 @@ void MolDraw2DSVG::drawEllipse(const Point2D &cds1, const Point2D &cds2,
 
   std::string col = DrawColourToSVG(colour());
   double width = getDrawLineWidth();
-  std::string dashString = "";
+  std::string dashString = getDashString(dash());
   d_os << "<ellipse"
        << " cx='" << MolDraw2D_detail::formatDouble(cx) << "'"
        << " cy='" << MolDraw2D_detail::formatDouble(cy) << "'"
