@@ -237,6 +237,12 @@ void readStereoGroups(RWMol *mol, const rj::Value &sgVals) {
     }
     const auto typ =
         MolInterchange::stereoGrouplookup.at(sgVal["type"].GetString());
+
+    unsigned gId = 0;
+    if (typ != StereoGroupType::STEREO_ABSOLUTE && sgVal.HasMember("id")) {
+      gId = sgVal["id"].GetUint();
+    }
+
     const auto &aids = sgVal["atoms"].GetArray();
     std::vector<Atom *> atoms;
     for (const auto &aid : aids) {
@@ -244,7 +250,7 @@ void readStereoGroups(RWMol *mol, const rj::Value &sgVals) {
     }
 
     if (!atoms.empty()) {
-      molSGs.emplace_back(typ, std::move(atoms));
+      molSGs.emplace_back(typ, std::move(atoms), gId);
     }
   }
   mol->setStereoGroups(std::move(molSGs));
@@ -915,15 +921,18 @@ std::vector<boost::shared_ptr<ROMol>> DocToMols(
   if (!doc.IsObject()) {
     throw FileParseException("Bad Format: JSON should be an object");
   }
+
   if (doc.HasMember("commonchem")) {
-    if (!doc["commonchem"].HasMember("version")) {
+    if (!doc["commonchem"].IsObject() ||
+        !doc["commonchem"].HasMember("version")) {
       throw FileParseException("Bad Format: missing version in JSON");
     }
     if (doc["commonchem"]["version"].GetInt() != currentMolJSONVersion) {
       throw FileParseException("Bad Format: bad version in JSON");
     }
   } else if (doc.HasMember("rdkitjson")) {
-    if (!doc["rdkitjson"].HasMember("version")) {
+    if (!doc["rdkitjson"].IsObject() ||
+        !doc["rdkitjson"].HasMember("version")) {
       throw FileParseException("Bad Format: missing version in JSON");
     }
     // FIX: we want to be backwards compatible
