@@ -268,15 +268,15 @@ void addProperties(const T &obj, const std::vector<std::string> &propNames,
     try {
       auto val = obj.template getProp<int>(pN);
       rjv = val;
-    } catch (const boost::bad_any_cast &) {
+    } catch (const std::bad_any_cast &) {
       try {
         auto val = obj.template getProp<double>(pN);
         rjv = val;
-      } catch (const boost::bad_any_cast &) {
+      } catch (const std::bad_any_cast &) {
         try {
           auto val = obj.template getProp<std::string>(pN);
           rjv.SetString(val.c_str(), val.size(), doc.GetAllocator());
-        } catch (const boost::bad_any_cast &) {
+        } catch (const std::bad_any_cast &) {
           BOOST_LOG(rdWarningLog)
               << "Warning: Could not convert property " << pN
               << " to a recognized type. Skipping it." << std::endl;
@@ -296,6 +296,11 @@ void addStereoGroup(const StereoGroup &sg, rj::Value &rjSG, rj::Document &doc) {
     throw ValueErrorException("unrecognized StereoGroup type");
   }
   addStringVal(rjSG, "type", inv_stereoGrouplookup.at(sg.getGroupType()), doc);
+
+  if (sg.getGroupType() != StereoGroupType::STEREO_ABSOLUTE) {
+    addIntVal(rjSG, "id", sg.getWriteId(), doc);
+  }
+
   rj::Value rjAtoms(rj::kArrayType);
   for (const auto atm : sg.getAtoms()) {
     rj::Value v1(static_cast<int>(atm->getIdx()));
