@@ -31,11 +31,12 @@
 
 using std::int32_t;
 using std::uint32_t;
+
 namespace RDKit {
 
-const int32_t MolPickler::versionMajor = 13;
+const int32_t MolPickler::versionMajor = 15;
 const int32_t MolPickler::versionMinor = 0;
-const int32_t MolPickler::versionPatch = 2;
+const int32_t MolPickler::versionPatch = 0;
 const int32_t MolPickler::endianId = 0xDEADBEEF;
 
 void streamWrite(std::ostream &ss, MolPickler::Tags tag) {
@@ -106,6 +107,165 @@ void write_sstream_to_stream(std::ostream &outStream,
 
 }  // namespace
 
+void MolPickler::_pickleProperties(std::ostream &ss, const RDProps &props,
+                                   unsigned int pickleFlags) {
+  if (!pickleFlags) {
+    return;
+  }
+
+  streamWriteProps<std::uint16_t>(ss, props,
+                                  pickleFlags & PicklerOps::PrivateProps,
+                                  pickleFlags & PicklerOps::ComputedProps,
+                                  MolPickler::getCustomPropHandlers());
+}
+
+namespace {
+
+template <typename SAVEAS, typename STOREAS>
+void unpickleExplicitProperties(
+    std::istream &ss, RDProps &props, int version,
+    const std::vector<std::pair<std::string, std::uint16_t>> &explicitProps) {
+  if (version >= 14000) {
+    std::uint8_t bprops;
+    streamRead(ss, bprops, version);
+    for (const auto &pr : explicitProps) {
+      if (bprops & pr.second) {
+        SAVEAS bv;
+        streamRead(ss, bv, version);
+        props.setProp(pr.first, static_cast<STOREAS>(bv));
+      }
+    }
+  }
+}
+
+template <typename SAVEAS>
+bool pickleExplicitProperties(
+    std::ostream &ss, const RDProps &props,
+    const std::vector<std::pair<std::string, std::uint16_t>> &explicitProps) {
+  std::uint8_t bprops = 0;
+  std::vector<SAVEAS> ps;
+  SAVEAS bv;
+  for (const auto &pr : explicitProps) {
+    if (props.getPropIfPresent(pr.first, bv)) {
+      bprops |= pr.second;
+      ps.push_back(bv);
+    }
+  }
+
+  streamWrite(ss, bprops);
+  for (auto v : ps) {
+    streamWrite(ss, v);
+  }
+  return !ps.empty();
+}
+
+// you're going to scratch your head and wonder why on earth this is using a
+// class instead of a set of globals. This is a workaround for some very strange
+// problem with globals and the cartridge
+class PropTracker {
+ public:
+  // this is stored as bitflags in a byte, so don't exceed 8 entries or we need
+  // to update the pickle format.
+  // the properties themselves are stored as std::int8_t
+  const std::vector<std::pair<std::string, std::uint16_t>> explicitBondProps = {
+      {RDKit::common_properties::_MolFileBondType, 0x1},
+      {RDKit::common_properties::_MolFileBondStereo, 0x2},
+      {RDKit::common_properties::_MolFileBondCfg, 0x4},
+      {RDKit::common_properties::_MolFileBondQuery, 0x8},
+      {RDKit::common_properties::molStereoCare, 0x10},
+  };
+  // this is stored as bitflags in a byte, so don't exceed 8 entries or we need
+  // to update the pickle format.
+  // the properties themselves are stored as std::int16_t
+  const std::vector<std::pair<std::string, std::uint16_t>> explicitAtomProps = {
+      {common_properties::molStereoCare, 0x1},
+      {common_properties::molParity, 0x2},
+      {common_properties::molInversionFlag, 0x4},
+      {common_properties::_ChiralityPossible, 0x8},
+
+  };
+  const std::vector<std::string> ignoreAtomProps = {
+      common_properties::molAtomMapNumber,
+      common_properties::dummyLabel,
+  };
+  std::unordered_set<std::string> ignoreBondProps;
+  PropTracker() {
+    for (const auto &pr : explicitBondProps) {
+      ignoreBondProps.insert(pr.first);
+    }
+  };
+};
+
+bool pickleAtomProperties(std::ostream &ss, const RDProps &props,
+                          unsigned int pickleFlags) {
+  const static PropTracker aprops;
+  static std::unordered_set<std::string> ignoreProps;
+  if (ignoreProps.empty()) {
+    for (const auto &pr : aprops.explicitAtomProps) {
+      ignoreProps.insert(pr.first);
+    }
+    for (const auto &pn : aprops.ignoreAtomProps) {
+      ignoreProps.insert(pn);
+    }
+  }
+
+  if (!pickleFlags) {
+    return false;
+  }
+
+  bool res = streamWriteProps<std::uint16_t>(
+      ss, props, pickleFlags & PicklerOps::PrivateProps,
+      pickleFlags & PicklerOps::ComputedProps,
+      MolPickler::getCustomPropHandlers(), ignoreProps);
+
+  res |= pickleExplicitProperties<std::int16_t>(ss, props,
+                                                aprops.explicitAtomProps);
+  return res;
+}
+
+void unpickleAtomProperties(std::istream &ss, RDProps &props, int version) {
+  const static PropTracker aprops;
+  if (version >= 14000) {
+    streamReadProps<std::uint16_t>(ss, props,
+                                   MolPickler::getCustomPropHandlers(), false);
+  } else {
+    streamReadProps<unsigned int>(ss, props,
+                                  MolPickler::getCustomPropHandlers(), false);
+  }
+  unpickleExplicitProperties<std::int16_t, int>(ss, props, version,
+                                                aprops.explicitAtomProps);
+}
+
+bool pickleBondProperties(std::ostream &ss, const RDProps &props,
+                          unsigned int pickleFlags) {
+  const static PropTracker bprops;
+  if (!pickleFlags) {
+    return false;
+  }
+  bool res = streamWriteProps<std::uint16_t>(
+      ss, props, pickleFlags & PicklerOps::PrivateProps,
+      pickleFlags & PicklerOps::ComputedProps,
+      MolPickler::getCustomPropHandlers(), bprops.ignoreBondProps);
+  res |= pickleExplicitProperties<std::int8_t>(ss, props,
+                                               bprops.explicitBondProps);
+  return res;
+}
+
+void unpickleBondProperties(std::istream &ss, RDProps &props, int version) {
+  const static PropTracker bprops;
+  if (version >= 14000) {
+    streamReadProps<std::uint16_t>(ss, props,
+                                   MolPickler::getCustomPropHandlers(), false);
+  } else {
+    streamReadProps<unsigned int>(ss, props,
+                                  MolPickler::getCustomPropHandlers(), false);
+  }
+  unpickleExplicitProperties<std::int8_t, int>(ss, props, version,
+                                               bprops.explicitBondProps);
+}
+
+}  // namespace
+
 unsigned int MolPickler::getDefaultPickleProperties() {
 #ifdef RDK_BUILD_THREADSAFE_SSS
   std::lock_guard<std::mutex> lock(GetPropMutex());
@@ -1005,35 +1165,40 @@ void MolPickler::_pickle(const ROMol *mol, std::ostream &ss,
   }
 
   if (propertyFlags & PicklerOps::MolProps) {
-    streamWrite(ss, BEGINPROPS);
     std::stringstream tss;
     _pickleProperties(tss, *mol, propertyFlags);
-    write_sstream_to_stream(ss, tss);
-    streamWrite(ss, ENDPROPS);
+    if (!tss.str().empty()) {
+      streamWrite(ss, BEGINPROPS);
+      write_sstream_to_stream(ss, tss);
+      streamWrite(ss, ENDPROPS);
+    }
   }
 
   if (propertyFlags & PicklerOps::AtomProps) {
-    streamWrite(ss, BEGINATOMPROPS);
     std::stringstream tss;
-    for (ROMol::ConstAtomIterator atIt = mol->beginAtoms();
-         atIt != mol->endAtoms(); ++atIt) {
-      _pickleProperties(tss, **atIt, propertyFlags);
+    bool anyWritten = false;
+    for (const auto atom : mol->atoms()) {
+      anyWritten |= pickleAtomProperties(tss, *atom, propertyFlags);
+    }
+    if (anyWritten) {
+      streamWrite(ss, BEGINATOMPROPS);
+      write_sstream_to_stream(ss, tss);
+      streamWrite(ss, ENDPROPS);
     }
-    write_sstream_to_stream(ss, tss);
-    streamWrite(ss, ENDPROPS);
   }
 
   if (propertyFlags & PicklerOps::BondProps) {
-    streamWrite(ss, BEGINBONDPROPS);
     std::stringstream tss;
-    for (ROMol::ConstBondIterator bondIt = mol->beginBonds();
-         bondIt != mol->endBonds(); ++bondIt) {
-      _pickleProperties(tss, **bondIt, propertyFlags);
+    bool anyWritten = false;
+    for (const auto bond : mol->bonds()) {
+      anyWritten |= pickleBondProperties(tss, *bond, propertyFlags);
+    }
+    if (anyWritten) {
+      streamWrite(ss, BEGINBONDPROPS);
+      write_sstream_to_stream(ss, tss);
+      streamWrite(ss, ENDPROPS);
     }
-    write_sstream_to_stream(ss, tss);
-    streamWrite(ss, ENDPROPS);
   }
-
   streamWrite(ss, ENDMOL);
 }
 
@@ -1174,7 +1339,7 @@ void MolPickler::_depickle(std::istream &ss, ROMol *mol, int version,
           ss.seekg(blkSize, std::ios_base::cur);
         } else {
           for (auto cid : cids) {
-            _unpickleProperties(ss, mol->getConformer(cid));
+            _unpickleProperties(ss, mol->getConformer(cid), version);
           }
         }
         streamRead(ss, tag, version);
@@ -1191,7 +1356,7 @@ void MolPickler::_depickle(std::istream &ss, ROMol *mol, int version,
       if (version >= 13000 && !(propertyFlags & PicklerOps::MolProps)) {
         ss.seekg(blkSize, std::ios_base::cur);
       } else {
-        _unpickleProperties(ss, *mol);
+        _unpickleProperties(ss, *mol, version);
       }
       streamRead(ss, tag, version);
     } else if (tag == BEGINATOMPROPS) {
@@ -1202,9 +1367,8 @@ void MolPickler::_depickle(std::istream &ss, ROMol *mol, int version,
       if (version >= 13000 && !(propertyFlags & PicklerOps::AtomProps)) {
         ss.seekg(blkSize, std::ios_base::cur);
       } else {
-        for (ROMol::AtomIterator atIt = mol->beginAtoms();
-             atIt != mol->endAtoms(); ++atIt) {
-          _unpickleProperties(ss, **atIt);
+        for (const auto atom : mol->atoms()) {
+          unpickleAtomProperties(ss, *atom, version);
         }
       }
       streamRead(ss, tag, version);
@@ -1216,16 +1380,14 @@ void MolPickler::_depickle(std::istream &ss, ROMol *mol, int version,
       if (version >= 13000 && !(propertyFlags & PicklerOps::BondProps)) {
         ss.seekg(blkSize, std::ios_base::cur);
       } else {
-        for (ROMol::BondIterator bdIt = mol->beginBonds();
-             bdIt != mol->endBonds(); ++bdIt) {
-          _unpickleProperties(ss, **bdIt);
+        for (const auto bond : mol->bonds()) {
+          unpickleBondProperties(ss, *bond, version);
         }
       }
       streamRead(ss, tag, version);
     } else if (tag == BEGINQUERYATOMDATA) {
-      for (ROMol::AtomIterator atIt = mol->beginAtoms();
-           atIt != mol->endAtoms(); ++atIt) {
-        _unpickleAtomData(ss, *atIt, version);
+      for (const auto atom : mol->atoms()) {
+        _unpickleAtomData(ss, atom, version);
       }
       streamRead(ss, tag, version);
     } else {
@@ -1244,9 +1406,7 @@ void MolPickler::_depickle(std::istream &ss, ROMol *mol, int version,
     // we didn't read any property info for atoms with associated
     // queries. update their property caches
     // (was sf.net Issue 3316407)
-    for (ROMol::AtomIterator atIt = mol->beginAtoms(); atIt != mol->endAtoms();
-         ++atIt) {
-      Atom *atom = *atIt;
+    for (const auto atom : mol->atoms()) {
       if (atom->hasQuery()) {
         atom->updatePropertyCache(false);
       }
@@ -1270,7 +1430,7 @@ bool getAtomMapNumber(const Atom *atom, int &mapNum) {
   int tmpInt;
   try {
     atom->getProp(common_properties::molAtomMapNumber, tmpInt);
-  } catch (boost::bad_any_cast &) {
+  } catch (std::bad_any_cast &) {
     const std::string &tmpSVal =
         atom->getProp<std::string>(common_properties::molAtomMapNumber);
     try {
@@ -1663,7 +1823,14 @@ Atom *MolPickler::_addAtomFromPickle(std::istream &ss, ROMol *mol,
         // the test for tmpChar below seems redundant, but on at least
         // the POWER8 architecture it seems that chars may be unsigned
         // by default.
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wtype-limits"
+#endif
         if ((tmpChar < 0 || tmpChar > 127) && version > 9000) {
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
           streamRead(ss, tmpInt, version);
         } else {
           tmpInt = tmpChar;
@@ -1734,6 +1901,10 @@ void MolPickler::_pickleBond(std::ostream &ss, const Bond *bond,
   if (bond->getStereo() != Bond::STEREONONE) {
     flags |= 0x1 << 1;
   }
+  std::string endpts;
+  if (bond->getPropIfPresent(common_properties::_MolFileBondEndPts, endpts)) {
+    flags |= 0x1;
+  }
   streamWrite(ss, flags);
 
   if (bond->getBondType() != Bond::SINGLE) {
@@ -1762,6 +1933,12 @@ void MolPickler::_pickleBond(std::ostream &ss, const Bond *bond,
     pickleQuery(ss, static_cast<const QueryBond *>(bond)->getQuery());
     streamWrite(ss, ENDQUERY);
   }
+  if (!endpts.empty()) {
+    streamWrite(ss, endpts);
+    std::string attach = "ALL";
+    bond->getPropIfPresent(common_properties::_MolFileBondAttach, attach);
+    streamWrite(ss, attach);
+  }
 }
 
 template <typename T>
@@ -1840,6 +2017,13 @@ Bond *MolPickler::_addBondFromPickle(std::istream &ss, ROMol *mol, int version,
       } else {
         bond->setStereo(Bond::STEREONONE);
       }
+      if (flags & 0x1) {
+        std::string tmpStr;
+        streamRead(ss, tmpStr, version);
+        bond->setProp(common_properties::_MolFileBondEndPts, tmpStr);
+        streamRead(ss, tmpStr, version);
+        bond->setProp(common_properties::_MolFileBondAttach, tmpStr);
+      }
     }
   }
   if (version > 5000 && hasQuery) {
@@ -1978,7 +2162,7 @@ void MolPickler::_pickleSubstanceGroup(std::ostream &ss,
                                        std::map<int, int> &bondIdxMap) {
   T tmpT;
 
-  streamWriteProps(ss, sgroup);
+  streamWriteProps<std::uint16_t>(ss, sgroup);
 
   const auto &atoms = sgroup.getAtoms();
   streamWrite(ss, static_cast<T>(atoms.size()));
@@ -2070,7 +2254,13 @@ SubstanceGroup MolPickler::_getSubstanceGroupFromPickle(std::istream &ss,
   SubstanceGroup sgroup(mol, "");
 
   // Read RDProps, overriding ID, TYPE and COMPNO
-  streamReadProps(ss, sgroup, MolPickler::getCustomPropHandlers());
+  if (version >= 14000) {
+    streamReadProps<std::uint16_t>(ss, sgroup,
+                                   MolPickler::getCustomPropHandlers());
+  } else {
+    streamReadProps<unsigned int>(ss, sgroup,
+                                  MolPickler::getCustomPropHandlers());
+  }
 
   streamRead(ss, numItems, version);
   for (int i = 0; i < numItems; ++i) {
@@ -2141,12 +2331,16 @@ SubstanceGroup MolPickler::_getSubstanceGroupFromPickle(std::istream &ss,
 
 template <typename T>
 void MolPickler::_pickleStereo(std::ostream &ss,
-                               const std::vector<StereoGroup> &groups,
+                               std::vector<StereoGroup> groups,
                                std::map<int, int> &atomIdxMap) {
   T tmpT = static_cast<T>(groups.size());
   streamWrite(ss, tmpT);
+  assignStereoGroupIds(groups);
   for (auto &&group : groups) {
     streamWrite(ss, static_cast<T>(group.getGroupType()));
+    if (group.getGroupType() != StereoGroupType::STEREO_ABSOLUTE) {
+      streamWrite(ss, static_cast<T>(group.getWriteId()));
+    }
     auto &atoms = group.getAtoms();
     streamWrite(ss, static_cast<T>(atoms.size()));
     for (auto &&atom : atoms) {
@@ -2169,6 +2363,12 @@ void MolPickler::_depickleStereo(std::istream &ss, ROMol *mol, int version) {
       streamRead(ss, tmpT, version);
       const auto groupType = static_cast<RDKit::StereoGroupType>(tmpT);
 
+      unsigned gId = 0;
+      if (version >= 14010 && groupType != StereoGroupType::STEREO_ABSOLUTE) {
+        streamRead(ss, tmpT, version);
+        gId = static_cast<unsigned>(tmpT);
+      }
+
       streamRead(ss, tmpT, version);
       const auto numAtoms = static_cast<unsigned>(tmpT);
 
@@ -2179,27 +2379,23 @@ void MolPickler::_depickleStereo(std::istream &ss, ROMol *mol, int version) {
         atoms.push_back(mol->getAtomWithIdx(tmpT));
       }
 
-      groups.emplace_back(groupType, std::move(atoms));
+      groups.emplace_back(groupType, std::move(atoms), gId);
     }
 
     mol->setStereoGroups(std::move(groups));
   }
 }
 
-void MolPickler::_pickleProperties(std::ostream &ss, const RDProps &props,
-                                   unsigned int pickleFlags) {
-  if (!pickleFlags) {
-    return;
-  }
-
-  streamWriteProps(ss, props, pickleFlags & PicklerOps::PrivateProps,
-                   pickleFlags & PicklerOps::ComputedProps,
-                   MolPickler::getCustomPropHandlers());
-}
-
 //! unpickle standard properties
-void MolPickler::_unpickleProperties(std::istream &ss, RDProps &props) {
-  streamReadProps(ss, props, MolPickler::getCustomPropHandlers());
+void MolPickler::_unpickleProperties(std::istream &ss, RDProps &props,
+                                     int version) {
+  if (version >= 14000) {
+    streamReadProps<std::uint16_t>(ss, props,
+                                   MolPickler::getCustomPropHandlers());
+  } else {
+    streamReadProps<unsigned int>(ss, props,
+                                  MolPickler::getCustomPropHandlers());
+  }
 }
 
 //--------------------------------------
