@@ -96,6 +96,12 @@ Reionizer::~Reionizer() { delete d_abcat; }
 // d_css(css) {};
 
 ROMol *Reionizer::reionize(const ROMol &mol) {
+  auto omol = new RWMol(mol);
+  this->reionizeInPlace(*omol);
+  return static_cast<ROMol *>(omol);
+}
+
+void Reionizer::reionizeInPlace(RWMol &mol) {
   PRECONDITION(this->d_abcat, "");
   const AcidBaseCatalogParams *abparams = this->d_abcat->getCatalogParams();
 
@@ -103,21 +109,20 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
   const std::vector<std::pair<ROMOL_SPTR, ROMOL_SPTR>> abpairs =
       abparams->getPairs();
 
-  auto *omol = new ROMol(mol);
-  if (omol->needsUpdatePropertyCache()) {
-    omol->updatePropertyCache(false);
+  if (mol.needsUpdatePropertyCache()) {
+    mol.updatePropertyCache(false);
   }
-  int start_charge = MolOps::getFormalCharge(*omol);
+  int start_charge = MolOps::getFormalCharge(mol);
 
   for (const auto &cc : this->d_ccs) {
     std::vector<MatchVectType> res;
     ROMOL_SPTR ccmol(SmartsToMol(cc.Smarts));
-    unsigned int matches = SubstructMatch(*omol, *ccmol, res);
+    unsigned int matches = SubstructMatch(mol, *ccmol, res);
     if (matches) {
       for (const auto &match : res) {
         for (const auto &pair : match) {
           auto idx = pair.second;
-          Atom *atom = omol->getAtomWithIdx(idx);
+          Atom *atom = mol.getAtomWithIdx(idx);
           BOOST_LOG(rdInfoLog)
               << "Applying charge correction " << cc.Name << " "
               << atom->getSymbol() << " " << cc.Charge << "\n";
@@ -126,7 +131,7 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
       }
     }
   }
-  int current_charge = MolOps::getFormalCharge(*omol);
+  int current_charge = MolOps::getFormalCharge(mol);
   int charge_diff = current_charge - start_charge;
   // std::cout << "Current charge: " << current_charge << std::endl;
   // std::cout << "Charge diff: " << charge_diff << std::endl;
@@ -140,7 +145,7 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
       // returns the acid strength ranking (ppos)
       // and the substruct match (poccur) in a pair
       std::shared_ptr<std::pair<unsigned int, std::vector<unsigned int>>> res(
-          this->strongestProtonated(*omol, abpairs));
+          this->strongestProtonated(mol, abpairs));
       if (res == nullptr) {
         break;
       } else {
@@ -151,7 +156,7 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
         (abpair.first)->getProp(common_properties::_Name, abname);
         BOOST_LOG(rdInfoLog) << "Ionizing " << abname
                              << " to balance previous charge corrections\n";
-        Atom *patom = omol->getAtomWithIdx(poccur.back());
+        Atom *patom = mol.getAtomWithIdx(poccur.back());
         patom->setFormalCharge(patom->getFormalCharge() - 1);
 
         if (patom->getNumExplicitHs() > 0) {
@@ -164,15 +169,15 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
     }
   }
 
-  // std::cout << MolToSmiles(*omol) << std::endl;
+  // std::cout << MolToSmiles(mol) << std::endl;
   // std::cout << "Charge diff: " << charge_diff << std::endl;
 
   std::set<std::vector<unsigned int>> already_moved;
   while (true) {
     std::shared_ptr<std::pair<unsigned int, std::vector<unsigned int>>> sp_res(
-        this->strongestProtonated(*omol, abpairs));
+        this->strongestProtonated(mol, abpairs));
     std::shared_ptr<std::pair<unsigned int, std::vector<unsigned int>>> wi_res(
-        this->weakestIonized(*omol, abpairs));
+        this->weakestIonized(mol, abpairs));
     if (sp_res != nullptr && wi_res != nullptr) {
       unsigned int ppos = sp_res->first;
       unsigned int ipos = wi_res->first;
@@ -206,9 +211,10 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
         BOOST_LOG(rdInfoLog) << "Moved proton from " << prot_name << " to "
                              << ionized_name << "\n";
         // Remove hydrogen from strongest protonated
-        Atom *patom = omol->getAtomWithIdx(poccur.back());
+        Atom *patom = mol.getAtomWithIdx(poccur.back());
         patom->setFormalCharge(patom->getFormalCharge() - 1);
-        // If no implicit Hs to autoremove, and at least 1 explicit H to remove,
+        // If no implicit Hs to autoremove, and at least 1 explicit H to
+        // remove,
         //  reduce explicit count by 1
         if (patom->getNumImplicitHs() == 0 && patom->getNumExplicitHs() > 0) {
           patom->setNumExplicitHs(patom->getNumExplicitHs() - 1);
@@ -217,7 +223,7 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
         patom->updatePropertyCache();
 
         // Add hydrogen to weakest ionized
-        Atom *iatom = omol->getAtomWithIdx(ioccur.back());
+        Atom *iatom = mol.getAtomWithIdx(ioccur.back());
         iatom->setFormalCharge(iatom->getFormalCharge() + 1);
         // Increase explicit H count if no implicit, or aromatic N or P,
         // or non default valence state
@@ -240,10 +246,6 @@ ROMol *Reionizer::reionize(const ROMol &mol) {
       break;
     }
   }  // while loop
-
-  // MolOps::sanitizeMol(*static_cast<RWMol *>(omol));
-
-  return omol;
 }
 
 std::pair<unsigned int, std::vector<unsigned int>>
@@ -340,10 +342,14 @@ bool neutralizeNegIfPossible(Atom *atom) {
 }
 
 ROMol *Uncharger::uncharge(const ROMol &mol) {
+  auto omol = new RWMol(mol);
+  this->unchargeInPlace(*omol);
+  return static_cast<ROMol *>(omol);
+}
+void Uncharger::unchargeInPlace(RWMol &mol) {
   BOOST_LOG(rdInfoLog) << "Running Uncharger\n";
-  auto *omol = new ROMol(mol);
-  if (omol->needsUpdatePropertyCache()) {
-    omol->updatePropertyCache(false);
+  if (mol.needsUpdatePropertyCache()) {
+    mol.updatePropertyCache(false);
   }
   std::vector<MatchVectType> p_matches;
   std::vector<MatchVectType> q_matches;
@@ -351,25 +357,25 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
   std::vector<MatchVectType> a_matches;
 
   // Get atom ids for matches
-  SubstructMatch(*omol, *(this->pos_h), p_matches);
-  SubstructMatch(*omol, *(this->pos_noh), q_matches);
+  SubstructMatch(mol, *(this->pos_h), p_matches);
+  SubstructMatch(mol, *(this->pos_noh), q_matches);
   unsigned int q_matched = 0;
   for (const auto &match : q_matches) {
-    q_matched += omol->getAtomWithIdx(match[0].second)->getFormalCharge();
+    q_matched += mol.getAtomWithIdx(match[0].second)->getFormalCharge();
   }
-  unsigned int n_matched = SubstructMatch(*omol, *(this->neg), n_matches);
-  unsigned int a_matched = SubstructMatch(*omol, *(this->neg_acid), a_matches);
+  unsigned int n_matched = SubstructMatch(mol, *(this->neg), n_matches);
+  unsigned int a_matched = SubstructMatch(mol, *(this->neg_acid), a_matches);
 
   // count the total number of negative atoms
   unsigned int n_neg = std::count_if(
-      omol->atoms().begin(), omol->atoms().end(),
+      mol.atoms().begin(), mol.atoms().end(),
       [](const auto atom) { return (atom->getFormalCharge() < 0); });
 
   bool needsNeutralization =
       (q_matched > 0 && (n_matched > 0 || a_matched > 0));
-  std::vector<unsigned int> atomRanks(omol->getNumAtoms());
+  std::vector<unsigned int> atomRanks(mol.getNumAtoms());
   if (df_canonicalOrdering && needsNeutralization) {
-    Canon::rankMolAtoms(*omol, atomRanks);
+    Canon::rankMolAtoms(mol, atomRanks);
   } else {
     std::iota(atomRanks.begin(), atomRanks.end(), 0);
   }
@@ -395,18 +401,19 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
     // Surplus negative charges more than non-neutralizable positive charges
     int neg_surplus = n_neg - q_matched;
     if (neg_surplus > 0 && n_matched) {
-      boost::dynamic_bitset<> nonAcids(omol->getNumAtoms());
+      boost::dynamic_bitset<> nonAcids(mol.getNumAtoms());
       nonAcids.set();
       for (const auto &pair : a_atoms) {
         nonAcids.reset(pair.second);
       }
-      // zwitterion with more negative charges than quaternary positive centres
+      // zwitterion with more negative charges than quaternary positive
+      // centres
       for (const auto &pair : n_atoms) {
         unsigned int idx = pair.second;
         if (!nonAcids[idx]) {
           continue;
         }
-        Atom *atom = omol->getAtomWithIdx(idx);
+        Atom *atom = mol.getAtomWithIdx(idx);
         if (neutralizeNegIfPossible(atom) && !--neg_surplus) {
           break;
         }
@@ -416,13 +423,13 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
     // now do the other negative groups if we still have charges left:
     neg_surplus = a_matched - q_matched;
     if (neg_surplus > 0) {
-      boost::dynamic_bitset<> skipChargeSep(omol->getNumAtoms());
+      boost::dynamic_bitset<> skipChargeSep(mol.getNumAtoms());
       for (const auto &pair : n_atoms) {
         unsigned int idx = pair.second;
-        Atom *atom = omol->getAtomWithIdx(idx);
+        Atom *atom = mol.getAtomWithIdx(idx);
         for (const auto &nbri :
-             boost::make_iterator_range(omol->getAtomNeighbors(atom))) {
-          const auto &nbr = (*omol)[nbri];
+             boost::make_iterator_range(mol.getAtomNeighbors(atom))) {
+          const auto &nbr = (mol)[nbri];
           auto nbrIdx = nbr->getIdx();
           // if the neighbor has a positive charge,
           // neutralize only once (e.g., NO3-)
@@ -436,12 +443,14 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
           }
         }
       }
-      // zwitterion with more negative charges than quaternary positive centres
+      // zwitterion with more negative charges than quaternary positive
+      // centres
       for (const auto &pair : a_atoms) {
         // Add hydrogen to first negative acidic atom, increase formal charge
-        // Until quaternary positive == negative total or no more negative atoms
+        // Until quaternary positive == negative total or no more negative
+        // atoms
         unsigned int idx = pair.second;
-        Atom *atom = omol->getAtomWithIdx(idx);
+        Atom *atom = mol.getAtomWithIdx(idx);
         // skip ahead if we already neutralized this or if it is part of a
         // zwitterion
         if (atom->getFormalCharge() >= 0 || skipChargeSep.test(idx)) {
@@ -457,14 +466,14 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
   } else {
     for (const auto &pair : n_atoms) {
       auto idx = pair.second;
-      Atom *atom = omol->getAtomWithIdx(idx);
+      Atom *atom = mol.getAtomWithIdx(idx);
       neutralizeNegIfPossible(atom);
     }
   }
 
   // Neutralize cations until there is no longer a net charge remaining:
   int netCharge = 0;
-  for (const auto &at : omol->atoms()) {
+  for (const auto &at : mol.atoms()) {
     netCharge += at->getFormalCharge();
   }
 
@@ -477,7 +486,7 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
       }
     }
     for (const auto &idx : p_idx_matches) {
-      Atom *atom = omol->getAtomWithIdx(idx);
+      Atom *atom = mol.getAtomWithIdx(idx);
       // atoms from places like Mol blocks are normally missing explicit Hs:
       atom->setNumExplicitHs(atom->getTotalNumHs());
       atom->setNoImplicit(true);
@@ -507,7 +516,6 @@ ROMol *Uncharger::uncharge(const ROMol &mol) {
       }
     }
   }
-  return omol;
 }  // namespace MolStandardize
 
 }  // namespace MolStandardize
