@@ -8,6 +8,7 @@
 //  of the RDKit source tree.
 //
 #include "Metal.h"
+#include <GraphMol/FileParsers/MolSGroupParsing.h>
 #include <GraphMol/SmilesParse/SmilesParse.h>
 #include <GraphMol/SmilesParse/SmilesWrite.h>
 #include <GraphMol/RDKitBase.h>
@@ -21,38 +22,56 @@ using namespace std;
 using namespace RDKit;
 namespace RDKit {
 class RWMol;
+
 class ROMol;
 
 namespace MolStandardize {
 
-MetalDisconnector::MetalDisconnector()
-    : metal_nof(
+MetalDisconnector::MetalDisconnector(const MetalDisconnectorOptions &options)
+    : dp_metal_nof(
           SmartsToMol("[Li,Na,K,Rb,Cs,Fr,Be,Mg,Ca,Sr,Ba,Ra,Sc,Ti,V,Cr,Mn,Fe,Co,"
                       "Ni,Cu,Zn,Al,Ga,Y,Zr,Nb,Mo,Tc,Ru,Rh,Pd,Ag,Cd,In,Sn,Hf,Ta,"
                       "W,Re,Os,Ir,Pt,Au,Hg,Tl,Pb,Bi]~[#7,#8,F]")),
-      metal_non(SmartsToMol(
-          "[Al,Sc,Ti,V,Cr,Mn,Fe,Co,Ni,Cu,Zn,Y,Zr,Nb,Mo,Tc,Ru,Rh,Pd,Ag,Cd,Hf,Ta,"
-          "W,Re,Os,Ir,Pt,Au]~[B,C,Si,P,As,Sb,S,Se,Te,Cl,Br,I,At]")) {
+      d_options(options) {
   BOOST_LOG(rdInfoLog) << "Initializing MetalDisconnector\n";
+  std::string metalList =
+      "Al,Sc,Ti,V,Cr,Mn,Fe,Co,Ni,Cu,Zn,Y,Zr,Nb,Mo,Tc,Ru,Rh,Pd,Ag,Cd,Hf,Ta,"
+      "W,Re,Os,Ir,Pt,Au]~";
+  std::string nonMetalList = "Si,P,As,Sb,S,Se,Te,Cl,Br,I,At]";
+  if (d_options.splitGrignards) {
+    metalList = "[Li,Na,Mg,K," + metalList;
+  } else {
+    metalList = "[" + metalList;
+  }
+  if (d_options.splitAromaticC) {
+    nonMetalList = "[B,#6," + nonMetalList;
+  } else {
+    nonMetalList = "[B,C," + nonMetalList;
+  }
+  std::string metal_non_smt = metalList + nonMetalList;
+  dp_metal_non.reset(RDKit::SmartsToMol(metal_non_smt));
+  std::string metalDummySmt = metalList + "[*]";
+  dp_metalDummy.reset(RDKit::SmartsToMol(metalDummySmt));
 };
 
-MetalDisconnector::MetalDisconnector(const MetalDisconnector &other) {
-  metal_nof = other.metal_nof;
-  metal_non = other.metal_non;
-};
+MetalDisconnector::MetalDisconnector(const MetalDisconnector &other)
+    : dp_metal_nof(other.dp_metal_nof),
+      dp_metal_non(other.dp_metal_non),
+      dp_metalDummy(other.dp_metalDummy),
+      d_options(other.d_options){};
 
 MetalDisconnector::~MetalDisconnector(){};
 
-ROMol *MetalDisconnector::getMetalNof() { return metal_nof.get(); }
+ROMol *MetalDisconnector::getMetalNof() { return dp_metal_nof.get(); }
 
-ROMol *MetalDisconnector::getMetalNon() { return metal_non.get(); }
+ROMol *MetalDisconnector::getMetalNon() { return dp_metal_non.get(); }
 
 void MetalDisconnector::setMetalNof(const ROMol &mol) {
-  this->metal_nof.reset(new ROMol(mol));
+  this->dp_metal_nof.reset(new ROMol(mol));
 }
 
 void MetalDisconnector::setMetalNon(const ROMol &mol) {
-  this->metal_non.reset(new ROMol(mol));
+  this->dp_metal_non.reset(new ROMol(mol));
 }
 
 ROMol *MetalDisconnector::disconnect(const ROMol &mol) {
@@ -63,7 +82,7 @@ ROMol *MetalDisconnector::disconnect(const ROMol &mol) {
 
 void MetalDisconnector::disconnect(RWMol &mol) {
   BOOST_LOG(rdInfoLog) << "Running MetalDisconnector\n";
-  std::list<ROMOL_SPTR> metalList = {metal_nof, metal_non};
+  std::list<ROMOL_SPTR> metalList = {dp_metal_nof, dp_metal_non};
   std::map<int, NonMetal> nonMetals;
   std::map<int, int> metalChargeExcess;
   for (auto &query : metalList) {
@@ -102,7 +121,17 @@ void MetalDisconnector::disconnect(RWMol &mol) {
     //	std::cout << "After removing bond and charge adjustment: " <<
     // MolToSmiles(mol) << std::endl;
   }
+  if (d_options.adjustCharges) {
+    adjust_charges(mol, nonMetals, metalChargeExcess);
+  }
+  if (d_options.removeHapticDummies) {
+    remove_haptic_dummies(mol);
+  }
+}
 
+void MetalDisconnector::adjust_charges(RDKit::RWMol &mol,
+                                       std::map<int, NonMetal> &nonMetals,
+                                       std::map<int, int> &metalChargeExcess) {
   for (auto it = nonMetals.begin(); it != nonMetals.end(); ++it) {
     auto a = mol.getAtomWithIdx(it->first);
     // do not blindly trust the original formal charge as it is often wrong
@@ -181,6 +210,13 @@ void MetalDisconnector::disconnect(RWMol &mol) {
     auto currentFc = a->getFormalCharge();
     const auto &valens =
         PeriodicTable::getTable()->getValenceList(a->getAtomicNum());
+    // valens should have at least -1 in it, as the atom data is currently
+    // configured, so max_element should never return valens.end().
+    auto max_valence = *std::max_element(valens.begin(), valens.end());
+    // Don't go over the maximum real valence.
+    if (max_valence != -1 && currentFc >= max_valence) {
+      continue;
+    }
     int fcAfterCut = it->second;
     if (currentFc > 0) {
       // if the original formal charge on the metal was positive, we trust it
@@ -189,6 +225,11 @@ void MetalDisconnector::disconnect(RWMol &mol) {
     }
     if (!valens.empty() && valens.front() != -1) {
       for (auto v = valens.begin(); v != valens.end(); ++v) {
+        // Some metals (e.g. Mg and Ba) have -1 as a final catchall, which
+        // is unhelpful for this.
+        if (*v == -1) {
+          continue;
+        }
         if (fcAfterCut > *v) {
           auto next = v + 1;
           if (next != valens.end() && fcAfterCut >= *v) {
@@ -212,5 +253,31 @@ void MetalDisconnector::disconnect(RWMol &mol) {
   }
 }
 
+void MetalDisconnector::remove_haptic_dummies(RDKit::RWMol &mol) {
+  std::vector<MatchVectType> matches;
+  SubstructMatch(mol, *dp_metalDummy, matches);
+  std::vector<unsigned int> dummiesToGo;
+  for (const auto &match : matches) {
+    int metal_idx = match[0].second;
+    int dummy_idx = match[1].second;
+    auto bond = mol.getBondBetweenAtoms(metal_idx, dummy_idx);
+    std::string sprop;
+    if (bond->getPropIfPresent(RDKit::common_properties::_MolFileBondEndPts,
+                               sprop)) {
+      if (sprop.length() > 4 && sprop[0] == '(' && sprop.back() == ')') {
+        dummiesToGo.push_back(dummy_idx);
+      }
+    }
+  }
+  // The atom indices are recalculated after each atom removal, so take them
+  // out in descending order. Bonds are taken out when the atom is removed.
+  std::sort(dummiesToGo.begin(), dummiesToGo.end(), std::greater{});
+  mol.beginBatchEdit();
+  for (auto a : dummiesToGo) {
+    mol.removeAtom(a);
+  }
+  mol.commitBatchEdit();
+}
+
 }  // namespace MolStandardize
 }  // namespace RDKit
