@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2018 Susan H. Leung
+//  Copyright (C) 2018-2021 Susan H. Leung and other RDKit contributors
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -8,8 +8,8 @@
 //  of the RDKit source tree.
 //
 #include <RDGeneral/export.h>
-#ifndef __RD_TRANSFORM_CATALOG_UTILS_H__
-#define __RD_TRANSFORM_CATALOG_UTILS_H__
+#ifndef RD_TRANSFORM_CATALOG_UTILS_H
+#define RD_TRANSFORM_CATALOG_UTILS_H
 
 #include <GraphMol/RDKitBase.h>
 #include "TransformCatalogParams.h"
@@ -27,6 +27,9 @@ RDKIT_MOLSTANDARDIZE_EXPORT std::vector<std::shared_ptr<ChemicalReaction>>
 readTransformations(std::string fileName);
 RDKIT_MOLSTANDARDIZE_EXPORT std::vector<std::shared_ptr<ChemicalReaction>>
 readTransformations(std::istream &inStream, int nToRead = -1);
+RDKIT_MOLSTANDARDIZE_EXPORT std::vector<std::shared_ptr<ChemicalReaction>>
+readTransformations(
+    const std::vector<std::pair<std::string, std::string>> &data);
 
 }  // namespace MolStandardize
 }  // namespace RDKit
