@@ -205,6 +205,11 @@ MolStandardize::TautomerEnumerator *createDefaultEnumerator() {
   return EnumeratorFromParams(ps);
 }
 
+MolStandardize::TautomerEnumerator *copyEnumerator(
+    const MolStandardize::TautomerEnumerator &other) {
+  return new MolStandardize::TautomerEnumerator(other);
+}
+
 class pyobjFunctor {
  public:
   pyobjFunctor(python::object obj) : dp_obj(std::move(obj)) {}
@@ -359,6 +364,7 @@ struct tautomer_wrapper {
         "TautomerEnumerator", python::no_init)
         .def("__init__", python::make_constructor(createDefaultEnumerator))
         .def("__init__", python::make_constructor(EnumeratorFromParams))
+        .def("__init__", python::make_constructor(copyEnumerator))
         .def("Enumerate", &enumerateHelper,
              (python::arg("self"), python::arg("mol")),
              python::return_value_policy<python::manage_new_object>(),
@@ -478,6 +484,10 @@ struct tautomer_wrapper {
         .def_readonly(
             "tautomerScoreVersion",
             MolStandardize::TautomerScoringFunctions::tautomerScoringVersion);
+    python::def("GetV1TautomerEnumerator",
+                MolStandardize::getV1TautomerEnumerator,
+                "return a TautomerEnumerator using v1 of the enumeration rules",
+                python::return_value_policy<python::manage_new_object>());
   }
 };
 
